@@ -31,6 +31,7 @@ import (
 // traitMetaDataGen produces YAML documentation about trait descriptions.
 type traitMetaDataGen struct {
 	generator.DefaultGen
+
 	arguments *args.GeneratorArgs
 	Root      *traitMetaDataRoot
 }
@@ -79,6 +80,7 @@ func (g *traitMetaDataGen) Filter(context *generator.Context, t *types.Type) boo
 			filter = false
 		}
 	}
+
 	return filter
 }
 
@@ -88,6 +90,7 @@ func (g *traitMetaDataGen) GenerateType(context *generator.Context, t *types.Typ
 	g.buildDescription(t, traitID, td)
 	g.buildFields(t, td)
 	g.Root.Traits = append(g.Root.Traits, *td)
+
 	return nil
 }
 
@@ -98,10 +101,11 @@ func (g *traitMetaDataGen) getTraitID(t *types.Type) string {
 			if len(matches) < 2 {
 				panic(fmt.Sprintf("unable to extract trait ID from tag line `%s`", s))
 			}
+
 			return matches[1]
 		}
 	}
-	panic(fmt.Sprintf("trait ID not found in type %s", t.Name.Name))
+	panic("trait ID not found in type " + t.Name.Name)
 }
 
 func (g *traitMetaDataGen) buildDescription(t *types.Type, traitID string, td *traitMetaData) {
