@@ -43,6 +43,7 @@ import (
 	. "github.com/apache/camel-k/v2/e2e/support/util"
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/prometheus/common/model"
 )
 
 func TestMetrics(t *testing.T) {
@@ -477,8 +478,11 @@ func TestMetrics(t *testing.T) {
 		t.Run("Integration first readiness metric", func(t *testing.T) {
 			var ts1, ts2 time.Time
 
-			// The start time is taken from the Integration status initialization timestamp
+			// Use DeploymentTimestamp if available (for dry-build), else use InitializationTimestamp
 			ts1 = it.Status.InitializationTimestamp.Time
+			if it.Status.DeploymentTimestamp != nil && !it.Status.DeploymentTimestamp.IsZero() {
+				ts1 = it.Status.DeploymentTimestamp.Time
+			}
 			g.Expect(ts1).NotTo(BeZero())
 			// The end time is reported into the ready condition first truthy time
 			ts2 = it.Status.GetCondition(v1.IntegrationConditionReady).FirstTruthyTime.Time
@@ -582,7 +586,7 @@ func buckets(value float64, upperBounds []float64) []*prometheus.Bucket {
 
 // https://prometheus.io/docs/instrumenting/exposition_formats/
 func parsePrometheusData(data []byte) (map[string]*prometheus.MetricFamily, error) {
-	var parser expfmt.TextParser
+	parser := expfmt.NewTextParser(model.UTF8Validation)
 	return parser.TextToMetricFamilies(bytes.NewReader(data))
 }
 
