@@ -56,6 +56,7 @@ type Integration struct {
 // The Integration will be watched by the operator which will be in charge to run the related application, according to the configuration specified.
 type IntegrationSpec struct {
 	// the number of `Pods` needed for the running Integration
+	// +kubebuilder:default=1
 	Replicas *int32 `json:"replicas,omitempty"`
 	// the sources which contain the Camel routes to run
 	Sources []SourceSpec `json:"sources,omitempty"`
@@ -132,6 +133,8 @@ type IntegrationStatus struct {
 	Capabilities []string `json:"capabilities,omitempty"`
 	// the timestamp representing the last time when this integration was initialized.
 	InitializationTimestamp *metav1.Time `json:"lastInitTimestamp,omitempty"`
+	// the timestamp representing the last time when this integration was deployed.
+	DeploymentTimestamp *metav1.Time `json:"lastDeploymentTimestamp,omitempty"`
 }
 
 // +kubebuilder:object:root=true
@@ -140,7 +143,8 @@ type IntegrationStatus struct {
 type IntegrationList struct {
 	metav1.TypeMeta `json:",inline"`
 	metav1.ListMeta `json:"metadata,omitempty"`
-	Items           []Integration `json:"items"`
+
+	Items []Integration `json:"items"`
 }
 
 // IntegrationPhase --.
@@ -162,9 +166,11 @@ const (
 	// IntegrationPhaseBuildingKit if building from a Camel route.
 	IntegrationPhaseBuildingKit IntegrationPhase = "Building Kit"
 	// IntegrationPhaseBuildSubmitted if building from a Git repository.
-	IntegrationPhaseBuildSubmitted IntegrationPhase = "BuildSubmitted"
+	IntegrationPhaseBuildSubmitted IntegrationPhase = "Build Submitted"
 	// IntegrationPhaseBuildRunning if building from a Git repository.
-	IntegrationPhaseBuildRunning IntegrationPhase = "BuildRunning"
+	IntegrationPhaseBuildRunning IntegrationPhase = "Build Running"
+	// IntegrationPhaseBuildComplete --.
+	IntegrationPhaseBuildComplete IntegrationPhase = "Build Complete"
 	// IntegrationPhaseDeploying --.
 	IntegrationPhaseDeploying IntegrationPhase = "Deploying"
 	// IntegrationPhaseRunning --.
@@ -304,13 +310,13 @@ type PodSpec struct {
 	// AutomountServiceAccountToken
 	AutomountServiceAccountToken *bool `json:"automountServiceAccountToken,omitempty" protobuf:"varint,21,opt,name=automountServiceAccountToken"`
 	// Volumes
-	Volumes []corev1.Volume `json:"volumes,omitempty" patchStrategy:"merge,retainKeys" patchMergeKey:"name" protobuf:"bytes,1,rep,name=volumes"`
+	Volumes []corev1.Volume `json:"volumes,omitempty" patchMergeKey:"name" patchStrategy:"merge,retainKeys" protobuf:"bytes,1,rep,name=volumes"`
 	// InitContainers
-	InitContainers []corev1.Container `json:"initContainers,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,20,rep,name=initContainers"`
+	InitContainers []corev1.Container `json:"initContainers,omitempty" patchMergeKey:"name" patchStrategy:"merge" protobuf:"bytes,20,rep,name=initContainers"`
 	// Containers
-	Containers []corev1.Container `json:"containers" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,2,rep,name=containers"`
+	Containers []corev1.Container `json:"containers" patchMergeKey:"name" patchStrategy:"merge" protobuf:"bytes,2,rep,name=containers"`
 	// EphemeralContainers
-	EphemeralContainers []corev1.EphemeralContainer `json:"ephemeralContainers,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,34,rep,name=ephemeralContainers"`
+	EphemeralContainers []corev1.EphemeralContainer `json:"ephemeralContainers,omitempty" patchMergeKey:"name" patchStrategy:"merge" protobuf:"bytes,34,rep,name=ephemeralContainers"`
 	// RestartPolicy
 	RestartPolicy corev1.RestartPolicy `json:"restartPolicy,omitempty" protobuf:"bytes,3,opt,name=restartPolicy,casttype=RestartPolicy"`
 	// TerminationGracePeriodSeconds
@@ -322,13 +328,13 @@ type PodSpec struct {
 	// NodeSelector
 	NodeSelector map[string]string `json:"nodeSelector,omitempty" protobuf:"bytes,7,rep,name=nodeSelector"`
 	// TopologySpreadConstraints
-	TopologySpreadConstraints []corev1.TopologySpreadConstraint `json:"topologySpreadConstraints,omitempty" patchStrategy:"merge" patchMergeKey:"topologyKey" protobuf:"bytes,33,opt,name=topologySpreadConstraints"`
+	TopologySpreadConstraints []corev1.TopologySpreadConstraint `json:"topologySpreadConstraints,omitempty" patchMergeKey:"topologyKey" patchStrategy:"merge" protobuf:"bytes,33,opt,name=topologySpreadConstraints"`
 	// PodSecurityContext
 	SecurityContext corev1.PodSecurityContext `json:"securityContext,omitempty" protobuf:"bytes,34,opt,name=securityContext"`
 }
 
 type PodCondition struct {
-	Name      string                `json:"name,omitempty" yaml:"name,omitempty"`
-	Condition corev1.PodCondition   `json:"condition" yaml:"condition"`
+	Name      string                `json:"name,omitempty"   yaml:"name,omitempty"`
+	Condition corev1.PodCondition   `json:"condition"        yaml:"condition"`
 	Health    []HealthCheckResponse `json:"health,omitempty" yaml:"health,omitempty"`
 }
