@@ -21,14 +21,15 @@ package trait
 //
 // +camel-k:trait=camel.
 type CamelTrait struct {
-	PlatformBaseTrait `property:",squash" json:",inline"`
+	PlatformBaseTrait `json:",inline" property:",squash"`
+
 	// The runtime provider to use for the integration. (Default, Camel K Runtime).
 	// +kubebuilder:validation:Enum=quarkus;plain-quarkus
-	RuntimeProvider string `property:"runtime-provider" json:"runtimeProvider,omitempty"`
+	RuntimeProvider string `json:"runtimeProvider,omitempty" property:"runtime-provider"`
 	// The runtime version to use for the integration. It overrides the default version set in the Integration Platform.
 	// You can use a fixed version (for example "3.2.3") or a semantic version (for example "3.x") which will try to resolve
 	// to the best matching Catalog existing on the cluster (Default, the one provided by the operator version).
-	RuntimeVersion string `property:"runtime-version" json:"runtimeVersion,omitempty"`
+	RuntimeVersion string `json:"runtimeVersion,omitempty" property:"runtime-version"`
 	// A list of properties to be provided to the Integration runtime
-	Properties []string `property:"properties" json:"properties,omitempty"`
+	Properties []string `json:"properties,omitempty" property:"properties"`
 }
