@@ -22,12 +22,13 @@ package trait
 //
 // +camel-k:trait=deployer.
 type DeployerTrait struct {
-	PlatformBaseTrait `property:",squash" json:",inline"`
-	// Allows to explicitly select the desired deployment kind between `deployment`, `cron-job` or `knative-service` when creating the resources for running the integration.
+	PlatformBaseTrait `json:",inline" property:",squash"`
+
+	// Deprecated: this feature will be removed in future releases.
+	// Allows to explicitly select the desired deployment kind between `deployment`, `cron-job` or `knative-service`
+	// when creating the resources for running the integration.
 	// +kubebuilder:validation:Enum=deployment;cron-job;knative-service
-	Kind string `property:"kind" json:"kind,omitempty"`
-	// Deprecated: won't be able to enforce client side update in the future.
-	// Use server-side apply to update the owned resources (default `true`).
-	// Note that it automatically falls back to client-side patching, if SSA is not available, e.g., on old Kubernetes clusters.
-	UseSSA *bool `property:"use-ssa" json:"useSSA,omitempty"`
+	Kind string `json:"kind,omitempty" property:"kind"`
+	// Deprecated: no longer in use.
+	UseSSA *bool `json:"useSSA,omitempty" property:"use-ssa"`
 }
