@@ -22,9 +22,10 @@ package trait
 //
 // +camel-k:trait=istio.
 type IstioTrait struct {
-	Trait `property:",squash" json:",inline"`
+	Trait `json:",inline" property:",squash"`
+
 	// Configures a (comma-separated) list of CIDR subnets that should not be intercepted by the Istio proxy (`10.0.0.0/8,172.16.0.0/12,192.168.0.0/16` by default).
-	Allow string `property:"allow" json:"allow,omitempty"`
+	Allow string `json:"allow,omitempty" property:"allow"`
 	// Forces the value for labels `sidecar.istio.io/inject`. By default the label is set to `true` on deployment and not set on Knative Service.
-	Inject *bool `property:"inject" json:"inject,omitempty"`
+	Inject *bool `json:"inject,omitempty" property:"inject"`
 }
