@@ -31,7 +31,6 @@ import (
 
 const cmdBind = "bind"
 
-// nolint: unparam
 func initializeBindCmdOptions(t *testing.T) (*bindCmdOptions, *cobra.Command, RootCmdOptions) {
 	t.Helper()
 
@@ -59,7 +58,7 @@ func TestBindOutputJSON(t *testing.T) {
 	assert.Equal(t, "json", buildCmdOptions.OutputFormat)
 
 	require.NoError(t, err)
-	assert.Equal(t, `{"kind":"Pipe","apiVersion":"camel.apache.org/v1","metadata":{"name":"my-to-my","creationTimestamp":null,"annotations":{"camel.apache.org/operator.id":"camel-k"}},"spec":{"source":{"uri":"my:src"},"sink":{"uri":"my:dst"}},"status":{}}`, output)
+	assert.Equal(t, `{"kind":"Pipe","apiVersion":"camel.apache.org/v1","metadata":{"name":"my-to-my","annotations":{"camel.apache.org/operator.id":"camel-k"}},"spec":{"source":{"uri":"my:src"},"sink":{"uri":"my:dst"}},"status":{}}`, output)
 }
 
 func TestBindOutputYAML(t *testing.T) {
@@ -73,7 +72,6 @@ kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-to-my
 spec:
   sink:
@@ -104,7 +102,6 @@ kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-to-my
 spec:
   errorHandler:
@@ -136,7 +133,6 @@ kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-to-my
 spec:
   errorHandler:
@@ -161,7 +157,6 @@ kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-to-my
 spec:
   errorHandler:
@@ -186,14 +181,16 @@ kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-    trait.camel.apache.org/mount.configs: configmap:my-cm
-  creationTimestamp: null
   name: my-to-my
 spec:
   sink:
     uri: my:dst
   source:
     uri: my:src
+  traits:
+    mount:
+      configs:
+      - configmap:my-cm
 status: {}
 `, output)
 }
@@ -210,14 +207,17 @@ kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-    trait.camel.apache.org/camel.properties: '[a=1,b=2]'
-  creationTimestamp: null
   name: my-to-my
 spec:
   sink:
     uri: my:dst
   source:
     uri: my:src
+  traits:
+    camel:
+      properties:
+      - a=1
+      - b=2
 status: {}
 `, output)
 }
@@ -236,7 +236,6 @@ kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-to-my
 spec:
   sink:
@@ -289,7 +288,6 @@ kind: Pipe
 metadata:
   annotations:
     camel.apache.org/operator.id: camel-k
-  creationTimestamp: null
   name: my-to-my
 spec:
   dependencies:
