@@ -19,8 +19,6 @@ package cmd
 
 import (
 	"testing"
-
-	"github.com/apache/camel-k/v2/pkg/util/test"
 )
 
 func TestLogsAlias(t *testing.T) {
@@ -30,7 +28,7 @@ func TestLogsAlias(t *testing.T) {
 
 	kamelTestPostAddCommandInit(t, rootCommand, options)
 
-	_, err := test.ExecuteCommand(rootCommand, "logs")
+	_, err := ExecuteCommand(rootCommand, "logs")
 
 	// in case of error we expect this to be the log default message
 	if err != nil && err.Error() != "log expects an integration name argument" {
