@@ -21,12 +21,14 @@ import (
 	"context"
 	"encoding/csv"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"log"
 	"reflect"
 	"strings"
 
 	"github.com/go-viper/mapstructure/v2"
+	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/client"
@@ -54,6 +56,7 @@ func DeleteIntegration(ctx context.Context, c client.Client, name string, namesp
 			Name:      name,
 		},
 	}
+
 	return c.Delete(ctx, &integration)
 }
 
@@ -198,10 +201,10 @@ func isOfflineCommand(cmd *cobra.Command) bool {
 
 func clone(dst interface{}, src interface{}) error {
 	if dst == nil {
-		return fmt.Errorf("dst cannot be nil")
+		return errors.New("dst cannot be nil")
 	}
 	if src == nil {
-		return fmt.Errorf("src cannot be nil")
+		return errors.New("src cannot be nil")
 	}
 
 	data, err := json.Marshal(src)
@@ -213,6 +216,7 @@ func clone(dst interface{}, src interface{}) error {
 	if err != nil {
 		return fmt.Errorf("unable to unmarshal into dst: %w", err)
 	}
+
 	return nil
 }
 
@@ -236,3 +240,33 @@ func fieldByMapstructureTagName(target reflect.Value, tagName string) (reflect.S
 
 	return reflect.StructField{}, false
 }
+
+func getIntegration(ctx context.Context, c client.Client, name, namespace string) (*v1.Integration, error) {
+	it := v1.NewIntegration(namespace, name)
+	key := k8sclient.ObjectKey{
+		Name:      name,
+		Namespace: namespace,
+	}
+	if err := c.Get(ctx, key, &it); err != nil {
+		return nil, err
+	}
+
+	return &it, nil
+}
+
+func getIntegrations(ctx context.Context, c client.Client, names []string, namespace string) ([]v1.Integration, error) {
+	ints := make([]v1.Integration, 0, len(names))
+	for _, n := range names {
+		it := v1.NewIntegration(namespace, n)
+		key := k8sclient.ObjectKey{
+			Name:      n,
+			Namespace: namespace,
+		}
+		if err := c.Get(ctx, key, &it); err != nil {
+			return nil, fmt.Errorf("could not find integration %s in namespace %s: %w", it.Name, namespace, err)
+		}
+		ints = append(ints, it)
+	}
+
+	return ints, nil
+}
