@@ -59,11 +59,6 @@ func LoadConfiguration() (*Config, error) {
 	return loadConfiguration(viper.ConfigFileUsed())
 }
 
-// LoadConfigurationFrom loads a kamel configuration file from a specific location.
-func LoadConfigurationFrom(location string) (*Config, error) {
-	return loadConfiguration(location)
-}
-
 func loadConfiguration(location string) (*Config, error) {
 	config := Config{
 		location: location,
@@ -158,6 +153,7 @@ func (cfg *Config) Save() error {
 	if err != nil {
 		return err
 	}
+
 	return os.WriteFile(cfg.location, data, io.FilePerm600)
 }
 
@@ -186,11 +182,14 @@ func (cfg *Config) navigate(values map[string]interface{}, prefix string, create
 			if create {
 				child := make(map[string]interface{})
 				values[node] = child
+
 				return child
 			}
+
 			return nil
 		}
 	}
+
 	return values
 }
 
@@ -201,5 +200,6 @@ func (cfg *Config) convert(m map[interface{}]interface{}) map[string]interface{}
 			res[ks] = v
 		}
 	}
+
 	return res
 }
