@@ -56,26 +56,31 @@ func newCmdVersion(rootCmdOptions *RootCmdOptions) (*cobra.Command, *versionCmdO
 		Annotations:       make(map[string]string),
 	}
 
-	cmd.Flags().Bool("operator", false, "Display Operator version")
+	cmd.Flags().Bool("operator", false, "Display Operator version. Deprecated option.")
 	cmd.Flags().BoolP("verbose", "v", false, "Display all available extra information")
-	cmd.Flags().BoolP("all", "a", false, "Display both Client and Operator version")
+	cmd.Flags().BoolP("all", "a", false, "Display both Client and Operator version. Deprecated option.")
 
 	return &cmd, &options
 }
 
 type versionCmdOptions struct {
 	*RootCmdOptions
+
+	// Deprecated: to be removed in future versions.
 	Operator bool `mapstructure:"operator"`
 	Verbose  bool `mapstructure:"verbose"`
-	All      bool `mapstructure:"all"`
+	// Deprecated: to be removed in future versions.
+	All bool `mapstructure:"all"`
 }
 
 func (o *versionCmdOptions) preRunE(cmd *cobra.Command, args []string) error {
 	if !o.Operator && !o.All {
 		// let the command to work in offline mode
 		cmd.Annotations[offlineCommandLabel] = "true"
+		fmt.Fprintf(cmd.OutOrStdout(), "Operator version discovery is deprecated. It will be removed from future releases.\n")
 	}
-	return o.RootCmdOptions.preRun(cmd, args)
+
+	return o.preRun(cmd, args)
 }
 
 func (o *versionCmdOptions) run(cmd *cobra.Command, _ []string) error {
@@ -93,6 +98,7 @@ func (o *versionCmdOptions) run(cmd *cobra.Command, _ []string) error {
 		}
 		o.displayOperatorVersion(cmd, c)
 	}
+
 	return nil
 }
 
@@ -127,6 +133,7 @@ func (o *versionCmdOptions) displayOperatorVersion(cmd *cobra.Command, c client.
 	}
 }
 
+// Deprecated: to be removed in future versions.
 func operatorInfo(ctx context.Context, c client.Client, namespace string) (map[string]string, error) {
 	infos := make(map[string]string)
 	platform, err := platformutil.GetOrFindLocal(ctx, c, namespace)
@@ -153,9 +160,9 @@ func operatorInfo(ctx context.Context, c client.Client, namespace string) (map[s
 		return nil, err
 	}
 	if catalog != nil {
-		infos["Camel Quarkus version"] = catalog.CamelCatalogSpec.GetCamelQuarkusVersion()
-		infos["Camel version"] = catalog.CamelCatalogSpec.GetCamelVersion()
-		infos["Quarkus version"] = catalog.CamelCatalogSpec.GetQuarkusVersion()
+		infos["Camel Quarkus version"] = catalog.GetCamelQuarkusVersion()
+		infos["Camel version"] = catalog.GetCamelVersion()
+		infos["Quarkus version"] = catalog.GetQuarkusVersion()
 	}
 
 	return infos, nil
@@ -166,6 +173,7 @@ func operatorVersion(ctx context.Context, c client.Client, namespace string) (st
 	if err != nil {
 		return "", err
 	}
+
 	return infos[infoVersion], nil
 }
 
@@ -176,11 +184,13 @@ func compatibleVersions(aVersion, bVersion string, cmd *cobra.Command) bool {
 	a, err := semver.NewVersion(aVersion)
 	if err != nil {
 		fmt.Fprintln(cmd.ErrOrStderr(), "Could not parse '"+aVersion+"' (error:", err.Error()+")")
+
 		return false
 	}
 	b, err := semver.NewVersion(bVersion)
 	if err != nil {
 		fmt.Fprintln(cmd.ErrOrStderr(), "Could not parse '"+bVersion+"' (error:", err.Error()+")")
+
 		return false
 	}
 	// We consider compatible when major and minor are equals
