@@ -25,6 +25,7 @@ import (
 	"github.com/apache/camel-k/v2/pkg/trait"
 	"github.com/apache/camel-k/v2/pkg/util/digest"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 func newBuildKitAction() Action {
@@ -54,6 +55,7 @@ func (action *buildKitAction) Handle(ctx context.Context, integration *v1.Integr
 		action.L.Info("Integration %s digest has changed: resetting its status. Will check if it needs to be rebuilt and restarted.", integration.Name)
 		integration.Initialize()
 		integration.Status.Digest = hash
+
 		return integration, nil
 	}
 
@@ -75,6 +77,7 @@ func (action *buildKitAction) Handle(ctx context.Context, integration *v1.Integr
 		err = fmt.Errorf("failed to lookup kits for integration %s/%s: %w", integration.Namespace, integration.Name, err)
 		integration.Status.Phase = v1.IntegrationPhaseError
 		integration.SetReadyConditionError(err.Error())
+
 		return integration, err
 	}
 
@@ -86,6 +89,7 @@ func (action *buildKitAction) Handle(ctx context.Context, integration *v1.Integr
 		err = fmt.Errorf("failed to apply traits to integration %s/%s: %w", integration.Namespace, integration.Name, err)
 		integration.Status.Phase = v1.IntegrationPhaseError
 		integration.SetReadyConditionError(err.Error())
+
 		return integration, err
 	}
 
@@ -104,6 +108,7 @@ kits:
 				err = fmt.Errorf("error occurred matches integration kits with environment for integration %s/%s: %w", integration.Namespace, integration.Name, err)
 				integration.Status.Phase = v1.IntegrationPhaseError
 				integration.SetReadyConditionError(err.Error())
+
 				return integration, err
 			}
 			if match {
@@ -128,6 +133,7 @@ kits:
 			err = fmt.Errorf("failed to create new integration kit for integration %s/%s: %w", integration.Namespace, integration.Name, err)
 			integration.Status.Phase = v1.IntegrationPhaseError
 			integration.SetReadyConditionError(err.Error())
+
 			return integration, err
 		}
 		if integrationKit == nil {
@@ -135,13 +141,20 @@ kits:
 		}
 	}
 
+	//nolint:nestif
 	if integrationKit != nil {
 		action.L.Debug("Setting integration kit for integration", "integration", integration.Name, "namespace", integration.Namespace, "integration kit", integrationKit.Name)
 		// Set the kit name so the next handle loop, will fall through the
 		// same path as integration with a user defined kit
 		integration.SetIntegrationKit(integrationKit)
 		if integrationKit.Status.Phase == v1.IntegrationKitPhaseReady {
-			integration.Status.Phase = v1.IntegrationPhaseDeploying
+			if integration.Annotations[v1.IntegrationDontRunAfterBuildAnnotation] == v1.IntegrationDontRunAfterBuildAnnotationTrueValue {
+				integration.Status.Phase = v1.IntegrationPhaseBuildComplete
+			} else {
+				now := metav1.Now().Rfc3339Copy()
+				integration.Status.DeploymentTimestamp = &now
+				integration.Status.Phase = v1.IntegrationPhaseDeploying
+			}
 		}
 	} else {
 		action.L.Debug("Not yet able to assign an integration kit to integration",
@@ -153,7 +166,6 @@ kits:
 }
 
 func (action *buildKitAction) checkIntegrationKit(ctx context.Context, integration *v1.Integration) (*v1.Integration, error) {
-
 	// IntegrationKit fully defined so find it
 	action.L.Debugf("Finding integration kit %s for integration %s\n",
 		integration.Status.IntegrationKit.Name, integration.Name)
@@ -170,7 +182,6 @@ func (action *buildKitAction) checkIntegrationKit(ctx context.Context, integrati
 		if err != nil {
 			return nil, fmt.Errorf("unable to match any integration kit with integration %s/%s: %w",
 				integration.Namespace, integration.Name, err)
-
 		}
 
 		if !match {
@@ -195,12 +206,20 @@ func (action *buildKitAction) checkIntegrationKit(ctx context.Context, integrati
 	if kit.Status.Phase == v1.IntegrationKitPhaseError {
 		integration.Status.Phase = v1.IntegrationPhaseError
 		integration.SetIntegrationKit(kit)
+
 		return integration, nil
 	}
 
 	if kit.Status.Phase == v1.IntegrationKitPhaseReady {
-		integration.Status.Phase = v1.IntegrationPhaseDeploying
+		if integration.Annotations[v1.IntegrationDontRunAfterBuildAnnotation] == v1.IntegrationDontRunAfterBuildAnnotationTrueValue {
+			integration.Status.Phase = v1.IntegrationPhaseBuildComplete
+		} else {
+			now := metav1.Now().Rfc3339Copy()
+			integration.Status.DeploymentTimestamp = &now
+			integration.Status.Phase = v1.IntegrationPhaseDeploying
+		}
 		integration.SetIntegrationKit(kit)
+
 		return integration, nil
 	}
 
