@@ -112,7 +112,7 @@ func (action *monitorAction) Handle(ctx context.Context, platform *v1.Integratio
 				v1.IntegrationPlatformConditionTypeRegistryAvailable,
 				corev1.ConditionTrue,
 				v1.IntegrationPlatformConditionTypeRegistryAvailableReason,
-				fmt.Sprintf("registry available at %s", platform.Status.Build.Registry.Address))
+				"registry available at "+platform.Status.Build.Registry.Address)
 			// Warn if insecure registry
 			if platform.Status.Build.Registry.Insecure {
 				platform.Status.SetCondition(
@@ -128,6 +128,7 @@ func (action *monitorAction) Handle(ctx context.Context, platform *v1.Integratio
 	}
 	action.checkTraitAnnotationsDeprecatedNotice(platform)
 	action.checkMavenSettings(platform)
+	action.checkKameletsCatalogRepoDeprecatedNotice(platform)
 	if err = action.addPlainQuarkusCatalog(ctx, catalog); err != nil {
 		// Only warn the user, we don't want to fail
 		action.L.Infof(
@@ -154,12 +155,28 @@ func (action *monitorAction) checkTraitAnnotationsDeprecatedNotice(platform *v1.
 					"WARN: annotation traits configuration is deprecated and will be removed soon. Use .spec.traits configuration for %s platform instead.",
 					platform.Name,
 				)
+
 				return
 			}
 		}
 	}
 }
 
+// Deprecated: to be removed in future versions, when we won't support any longer Kamelets catalog into IntegrationPlatforms.
+func (action *monitorAction) checkKameletsCatalogRepoDeprecatedNotice(platform *v1.IntegrationPlatform) {
+	if platform.Status.Kamelet.Repositories != nil {
+		platform.Status.SetCondition(
+			v1.IntegrationPlatformConditionType("KameletsCatalogRepositoryDeprecated"),
+			corev1.ConditionTrue,
+			"DeprecationNotice",
+			"Kamelets Catalog Repository is deprecated and will be removed soon. Bundle Kamelets into a Maven dependency instead.",
+		)
+		action.L.Infof(
+			"Kamelets Catalog Repository is deprecated and will be removed soon from IntegrationPlatform configuration. " +
+				"Bundle Kamelets into a Maven dependency instead")
+	}
+}
+
 func (action *monitorAction) checkMavenSettings(platform *v1.IntegrationPlatform) {
 	if platform.Status.Build.Maven.Settings.ConfigMapKeyRef != nil ||
 		platform.Status.Build.Maven.Settings.SecretKeyRef != nil {
@@ -188,6 +205,7 @@ func specOrDefault(runtimeVersionSpec string) string {
 	if runtimeVersionSpec == "" {
 		return defaults.DefaultRuntimeVersion
 	}
+
 	return runtimeVersionSpec
 }
 
