@@ -20,6 +20,7 @@ package pipe
 import (
 	"context"
 	"fmt"
+	"strings"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
@@ -47,7 +48,8 @@ func (action *monitorAction) Name() string {
 func (action *monitorAction) CanHandle(pipe *v1.Pipe) bool {
 	return pipe.Status.Phase == v1.PipePhaseCreating ||
 		pipe.Status.Phase == v1.PipePhaseError ||
-		pipe.Status.Phase == v1.PipePhaseReady
+		pipe.Status.Phase == v1.PipePhaseReady ||
+		pipe.Status.Phase == v1.PipePhaseBuildComplete
 }
 
 func (action *monitorAction) Handle(ctx context.Context, pipe *v1.Pipe) (*v1.Pipe, error) {
@@ -58,6 +60,7 @@ func (action *monitorAction) Handle(ctx context.Context, pipe *v1.Pipe) (*v1.Pip
 	it := v1.Integration{}
 	if err := action.client.Get(ctx, key, &it); err != nil && k8serrors.IsNotFound(err) {
 		action.L.Info("Re-initializing Pipe")
+
 		return initializePipe(ctx, action.client, action.L, pipe)
 	} else if err != nil {
 		return nil, fmt.Errorf("could not load integration for Pipe %q: %w", pipe.Name, err)
@@ -86,6 +89,7 @@ func (action *monitorAction) Handle(ctx context.Context, pipe *v1.Pipe) (*v1.Pip
 			"IntegrationError",
 			err,
 		)
+
 		return pipe, err
 	}
 
@@ -109,6 +113,7 @@ func (action *monitorAction) Handle(ctx context.Context, pipe *v1.Pipe) (*v1.Pip
 			"",
 			"",
 		)
+
 		return target, nil
 	}
 
@@ -116,7 +121,6 @@ func (action *monitorAction) Handle(ctx context.Context, pipe *v1.Pipe) (*v1.Pip
 	target := pipe.DeepCopy()
 
 	switch it.Status.Phase {
-
 	case v1.IntegrationPhaseRunning:
 		target.Status.Phase = v1.PipePhaseReady
 		setPipeReadyCondition(target, &it)
@@ -125,6 +129,16 @@ func (action *monitorAction) Handle(ctx context.Context, pipe *v1.Pipe) (*v1.Pip
 		target.Status.Phase = v1.PipePhaseError
 		setPipeReadyCondition(target, &it)
 
+	case v1.IntegrationPhaseBuildComplete:
+		target.Status.Phase = v1.PipePhaseBuildComplete
+		c := v1.PipeCondition{
+			Type:    v1.PipeConditionReady,
+			Status:  corev1.ConditionFalse,
+			Reason:  "BuildComplete",
+			Message: fmt.Sprintf("Integration %q build completed successfully", it.GetName()),
+		}
+		target.Status.SetConditions(c)
+
 	default:
 		target.Status.Phase = v1.PipePhaseCreating
 
@@ -149,6 +163,8 @@ func (action *monitorAction) Handle(ctx context.Context, pipe *v1.Pipe) (*v1.Pip
 	target.Status.Replicas = it.Status.Replicas
 	target.Status.Selector = it.Status.Selector
 
+	action.checkTraitAnnotationsDeprecatedNotice(target)
+
 	return target, nil
 }
 
@@ -172,7 +188,6 @@ func setPipeReadyCondition(kb *v1.Pipe, it *v1.Integration) {
 		}
 
 		kb.Status.SetConditions(c)
-
 	} else {
 		kb.Status.SetCondition(
 			v1.PipeConditionReady,
@@ -182,3 +197,25 @@ func setPipeReadyCondition(kb *v1.Pipe, it *v1.Integration) {
 		)
 	}
 }
+
+// Deprecated: to be removed in future versions, when we won't support any longer trait annotations into Pipes.
+func (action *monitorAction) checkTraitAnnotationsDeprecatedNotice(pipe *v1.Pipe) {
+	if pipe.Annotations != nil {
+		for k := range pipe.Annotations {
+			if strings.HasPrefix(k, v1.TraitAnnotationPrefix) {
+				pipe.Status.SetCondition(
+					v1.PipeConditionType("AnnotationTraitsDeprecated"),
+					corev1.ConditionTrue,
+					"DeprecationNotice",
+					"Annotation traits configuration is deprecated and will be removed soon. Use .spec.traits configuration instead.",
+				)
+				action.L.Infof(
+					"WARN: annotation traits configuration is deprecated and will be removed soon. Use .spec.traits configuration for %s pipe instead.",
+					pipe.Name,
+				)
+
+				return
+			}
+		}
+	}
+}
