@@ -294,7 +294,7 @@ func notifyIfConditionUpdated(recorder record.EventRecorder, newResource runtime
 	for _, cond := range getCommonChangedConditions(oldConditions, newConditions) {
 		tail := ""
 		if cond.GetMessage() != "" {
-			tail = fmt.Sprintf(": %s", cond.GetMessage())
+			tail = ": " + cond.GetMessage()
 		}
 		recorder.Eventf(newResource, corev1.EventTypeNormal, reason, "Condition %q is %q for %s %s%s", cond.GetType(), cond.GetStatus(), resourceType, name, tail)
 	}
@@ -313,6 +313,7 @@ func getCommonChangedConditions(oldConditions, newConditions []v1.ResourceCondit
 			res = append(res, newCond)
 		}
 	}
+
 	return res
 }
 
@@ -322,10 +323,13 @@ func getCreatorObject(ctx context.Context, c client.Client, obj runtime.Object)
 			it := v1.NewIntegration(ref.Namespace, ref.Name)
 			if err := c.Get(ctx, ctrl.ObjectKeyFromObject(&it), &it); err != nil {
 				log.Infof("Cannot get information about the creator Integration %v: %v", ref, err)
+
 				return nil, nil
 			}
+
 			return ref, &it
 		}
 	}
+
 	return nil, nil
 }
