@@ -30,8 +30,8 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
-	"github.com/apache/camel-k/v2/pkg/util/test"
 
+	"github.com/apache/camel-k/v2/pkg/internal"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -114,7 +114,7 @@ func TestApplyCamelTraitWithoutEnvironmentCatalogAndUnmatchableVersionFails(t *t
 }
 
 func createNominalCamelTest(withSources bool) (*camelTrait, *Environment) {
-	client, _ := test.NewFakeClient()
+	client, _ := internal.NewFakeClient()
 
 	trait, _ := newCamelTrait().(*camelTrait)
 	var sources []v1.SourceSpec
