@@ -45,9 +45,10 @@ const (
 	containerTraitID    = "container"
 	containerTraitOrder = 1600
 
-	defaultContainerName = "integration"
-	defaultContainerPort = 8080
-	defaultServicePort   = 80
+	defaultContainerName       = "integration"
+	defaultContainerAnnotation = "kubectl.kubernetes.io/default-container"
+	defaultContainerPort       = 8080
+	defaultServicePort         = 80
 
 	defaultContainerRunAsNonRoot             = false
 	defaultContainerSeccompProfileType       = corev1.SeccompProfileTypeRuntimeDefault
@@ -63,7 +64,8 @@ const (
 type containerTrait struct {
 	BasePlatformTrait
 	traitv1.ContainerTrait `property:",squash"`
-	containerPorts         []containerPort
+
+	containerPorts []containerPort
 }
 
 // containerPort is supporting port parsing.
@@ -116,6 +118,7 @@ func (t *containerTrait) Apply(e *Environment) error {
 	if err := t.configureImageIntegrationKit(e); err != nil {
 		return err
 	}
+
 	return t.configureContainer(e)
 }
 
@@ -165,6 +168,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 		}
 		containers = &deployment.Spec.Template.Spec.Containers
 		visited = true
+
 		return nil
 	}); err != nil {
 		return err
@@ -185,9 +189,10 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 				envvar.SetVar(&container.Env, env)
 			}
 		}
-		containers = &service.Spec.ConfigurationSpec.Template.Spec.Containers
+		containers = &service.Spec.Template.Spec.Containers
 		visited = true
 		knative = true
+
 		return nil
 	}); err != nil {
 		return err
@@ -199,6 +204,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 		}
 		containers = &cron.Spec.JobTemplate.Spec.Template.Spec.Containers
 		visited = true
+
 		return nil
 	}); err != nil {
 		return err
