@@ -18,6 +18,7 @@ limitations under the License.
 package trait
 
 import (
+	"errors"
 	"fmt"
 	"regexp"
 	"strconv"
@@ -119,6 +120,7 @@ func (t *cronTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 				"fallback strategy selected",
 			)
 		}
+
 		return true, condition, nil
 	}
 
@@ -171,6 +173,7 @@ func (t *cronTrait) autoConfigure(e *Environment) error {
 		for _, fromURI := range fromURIs {
 			if uri.GetComponent(fromURI) == genericCronComponent {
 				t.Fallback = ptr.To(true)
+
 				break
 			}
 		}
@@ -199,7 +202,7 @@ func (t *cronTrait) Apply(e *Environment) error {
 		}
 		cronComponentArtifact := e.CamelCatalog.GetArtifactByScheme("timer")
 		if cronComponentArtifact == nil {
-			return fmt.Errorf("no timer artifact has been found in camel catalog")
+			return errors.New("no timer artifact has been found in camel catalog")
 		}
 		util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, cronComponentArtifact.GetDependencyID())
 	}
@@ -237,6 +240,9 @@ func (t *cronTrait) getCronJobFor(e *Environment) *batchv1.CronJob {
 		}
 	}
 
+	// Set the default container annotation for kubectl commands
+	annotations[defaultContainerAnnotation] = defaultContainerName
+
 	activeDeadline := defaultCronActiveDeadlineSeconds
 	if t.ActiveDeadlineSeconds != nil {
 		activeDeadline = *t.ActiveDeadlineSeconds
@@ -303,6 +309,7 @@ func (t *cronTrait) SelectControllerStrategy(e *Environment) (*ControllerStrateg
 			return &cronStrategy, nil
 		}
 	}
+
 	return nil, nil
 }
 
@@ -320,11 +327,13 @@ func (c *cronInfo) withComponents(components ...string) *cronInfo {
 	for _, comp := range components {
 		util.StringSliceUniqueAdd(&c.components, comp)
 	}
+
 	return c
 }
 
 func (c *cronInfo) withSchedule(schedule string) *cronInfo {
 	c.schedule = schedule
+
 	return c
 }
 
@@ -339,6 +348,7 @@ func (t *cronTrait) getGlobalCron(e *Environment) (*cronInfo, error) {
 		if scheme.Passive {
 			passiveComponents[id] = true
 		}
+
 		return true
 	})
 
@@ -353,6 +363,7 @@ func (t *cronTrait) getGlobalCron(e *Environment) (*cronInfo, error) {
 	}
 
 	globalCron := getCronForURIs(cron)
+
 	return globalCron, nil
 }
 
@@ -360,6 +371,7 @@ func (t *cronTrait) getSourcesFromURIs(e *Environment) ([]string, error) {
 	var fromUris []string
 	_, err := e.ConsumeMeta(true, func(meta metadata.IntegrationMetadata) bool {
 		fromUris = meta.FromURIs
+
 		return true
 	})
 	if err != nil {
@@ -393,12 +405,14 @@ func getCronForURIs(camelURIs []string) *cronInfo {
 			globalCron = globalCron.withComponents(cr.components...)
 		}
 	}
+
 	return globalCron
 }
 
 func getCronForURI(camelURI string) *cronInfo {
 	comp := uri.GetComponent(camelURI)
 	extractor := supportedCamelComponents[comp]
+
 	return extractor(camelURI)
 }
 
@@ -439,6 +453,7 @@ func timerToCronInfo(camelURI string) *cronInfo {
 			return newCronInfo().withComponents("timer").withSchedule(fmt.Sprintf("0/%d * * * ?", minutes))
 		}
 	}
+
 	return nil
 }
 
@@ -477,6 +492,7 @@ func cronEquivalent(cron1, cron2 string) bool {
 	// best effort to determine if two crons are equivalent
 	cron1 = strings.ReplaceAll(cron1, "?", "*")
 	cron2 = strings.ReplaceAll(cron2, "?", "*")
+
 	return cron1 == cron2
 }
 
@@ -500,6 +516,7 @@ func toKubernetesCronSchedule(cron string) string {
 	if len(parts) == 5 {
 		return strings.Join(parts, " ")
 	}
+
 	return ""
 }
 
@@ -508,6 +525,7 @@ func checkedStringToUint64(str string) uint64 {
 	if err != nil {
 		panic(err)
 	}
+
 	return res
 }
 
