@@ -115,11 +115,23 @@ func (t *gcTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 
 	// We need to execute this trait only when all resources have been created and
 	// deployed with a new generation if there is was any change during the Integration drift.
-	return e.IntegrationInRunningPhases(), nil, nil
+	return e.IntegrationInRunningPhases() || e.IntegrationInPhase(v1.IntegrationPhaseBuildComplete), nil, nil
 }
 
 func (t *gcTrait) Apply(e *Environment) error {
-	if e.Integration.GetGeneration() > 1 {
+	// Garbage collection runs when:
+	// 1. Generation > 1: resource was updated, clean up old generation resources
+	// 2. BuildComplete phase AND integration has previously been deployed: undeploy scenario
+	shouldRunGC := e.Integration.GetGeneration() > 1
+
+	if !shouldRunGC && e.IntegrationInPhase(v1.IntegrationPhaseBuildComplete) {
+		// Only run GC if integration was previously deployed (undeploy case)
+		if !hasNeverDeployed(e.Integration) {
+			shouldRunGC = true
+		}
+	}
+
+	if shouldRunGC {
 		// Register a post action that deletes the existing resources that are labelled
 		// with the previous integration generation(s).
 		// We make the assumption generation is a monotonically increasing strictly positive integer,
@@ -141,6 +153,7 @@ func (t *gcTrait) Apply(e *Environment) error {
 			resourceLabels[v1.IntegrationLabel] = env.Integration.Name
 			resource.SetLabels(resourceLabels)
 		})
+
 		return nil
 	})
 
@@ -187,12 +200,20 @@ func (t *gcTrait) garbageCollectResources(e *Environment) error {
 		return fmt.Errorf("cannot determine generation requirement: %w", err)
 	}
 	selector := labels.NewSelector().
-		Add(*integration).
-		Add(*generation)
+		Add(*integration)
+
+	// On undeploy, delete all resources regardless of generation.
+	// On generation upgrade, filter to only delete old resources.
+	isUndeploying := e.IntegrationInPhase(v1.IntegrationPhaseBuildComplete) && !hasNeverDeployed(e.Integration)
+	if !isUndeploying {
+		selector = selector.Add(*generation)
+	}
 
 	return t.deleteEachOf(e.Ctx, deletableGVKs, e, selector)
 }
 
+// deleteEachOf takes care of the effective deletion of each deletableGVKs passed for the given selector. It should be any older generation resource
+// of the Integration.
 func (t *gcTrait) deleteEachOf(ctx context.Context, deletableGVKs map[schema.GroupVersionKind]struct{}, e *Environment, selector labels.Selector) error {
 	for GVK := range deletableGVKs {
 		resources := unstructured.UnstructuredList{
@@ -209,12 +230,13 @@ func (t *gcTrait) deleteEachOf(ctx context.Context, deletableGVKs map[schema.Gro
 			if !k8serrors.IsNotFound(err) {
 				return fmt.Errorf("cannot list child resources: %w", err)
 			}
+
 			continue
 		}
 
 		for _, resource := range resources.Items {
 			r := resource
-			if !t.canBeDeleted(e, r) {
+			if !canBeDeleted(e.Integration, r) {
 				continue
 			}
 			err := t.Client.Delete(ctx, &r, ctrl.PropagationPolicy(metav1.DeletePropagationBackground))
@@ -232,16 +254,36 @@ func (t *gcTrait) deleteEachOf(ctx context.Context, deletableGVKs map[schema.Gro
 	return nil
 }
 
-func (t *gcTrait) canBeDeleted(e *Environment, u unstructured.Unstructured) bool {
-	// Only delete direct children of the integration, otherwise we can affect the behavior of external controllers (i.e. Knative)
+// canBeDeleted is an important security check. We make sure that we are only deleting those resources belonging to the given Integration.
+func canBeDeleted(it *v1.Integration, u unstructured.Unstructured) bool {
 	for _, o := range u.GetOwnerReferences() {
-		if o.Kind == v1.IntegrationKind && strings.HasPrefix(o.APIVersion, v1.SchemeGroupVersion.Group) && o.Name == e.Integration.Name {
+		if o.Kind == v1.IntegrationKind && strings.HasPrefix(o.APIVersion, v1.SchemeGroupVersion.Group) && o.Name == it.Name {
 			return true
 		}
 	}
+
 	return false
 }
 
+// hasNeverDeployed returns true if the integration has never been deployed.
+// Checks both DeploymentTimestamp and Ready condition for reliability.
+func hasNeverDeployed(integration *v1.Integration) bool {
+	// Primary check: DeploymentTimestamp is set when deployment is triggered
+	if integration.Status.DeploymentTimestamp != nil && !integration.Status.DeploymentTimestamp.IsZero() {
+		return false // has been deployed
+	}
+
+	// Secondary check: Ready condition becomes true only after successful deployment
+	readyCond := integration.Status.GetCondition(v1.IntegrationConditionReady)
+	if readyCond != nil && readyCond.FirstTruthyTime != nil && !readyCond.FirstTruthyTime.IsZero() {
+		return false
+	}
+
+	return true
+}
+
+// getDeletableTypes returns the list of deletable types resources, inspecting the rules for which the operator SA is allowed in the
+// Integration namespace.
 func (t *gcTrait) getDeletableTypes(e *Environment) (map[schema.GroupVersionKind]struct{}, error) {
 	lock.Lock()
 	defer lock.Unlock()
@@ -253,6 +295,7 @@ func (t *gcTrait) getDeletableTypes(e *Environment) (map[schema.GroupVersionKind
 	if !rateLimiter.Allow() {
 		// Return the cached set of garbage collectable GVKs.
 		maps.Copy(GVKs, collectableGVKs)
+
 		return GVKs, nil
 	}
 
@@ -303,6 +346,7 @@ func (t *gcTrait) getDeletableTypes(e *Environment) (map[schema.GroupVersionKind
 						if (resourceGroup == ruleGroup || ruleGroup == "*") && (resource.Name == ruleResource || ruleResource == "*") {
 							GVK := schema.FromAPIVersionAndKind(APIResourceList.GroupVersion, resource.Kind)
 							GVKs[GVK] = struct{}{}
+
 							break rule
 						}
 					}
