@@ -18,6 +18,7 @@ limitations under the License.
 package trait
 
 import (
+	"errors"
 	"fmt"
 	"sort"
 
@@ -105,6 +106,7 @@ func (t *healthTrait) Apply(e *Environment) error {
 			// sort the dependencies to get always the same list if they don't change
 			sort.Strings(e.Integration.Status.Dependencies)
 		}
+
 		return nil
 	}
 
@@ -131,19 +133,19 @@ func (t *healthTrait) Apply(e *Environment) error {
 func (t *healthTrait) setProbes(container *corev1.Container, port *intstr.IntOrString) error {
 	if ptr.Deref(t.LivenessProbeEnabled, false) {
 		if t.LivenessProbe == "" {
-			return fmt.Errorf("you need to configure a liveness probe explicitly or in your catalog")
+			return errors.New("you need to configure a liveness probe explicitly or in your catalog")
 		}
 		container.LivenessProbe = t.newLivenessProbe(port, t.LivenessProbe)
 	}
 	if ptr.Deref(t.ReadinessProbeEnabled, true) {
 		if t.ReadinessProbe == "" {
-			return fmt.Errorf("you need to configure a readiness probe explicitly or in your catalog")
+			return errors.New("you need to configure a readiness probe explicitly or in your catalog")
 		}
 		container.ReadinessProbe = t.newReadinessProbe(port, t.ReadinessProbe)
 	}
 	if ptr.Deref(t.StartupProbeEnabled, false) {
 		if t.StartupProbe == "" {
-			return fmt.Errorf("you need to configure a startup probe explicitly or in your catalog")
+			return errors.New("you need to configure a startup probe explicitly or in your catalog")
 		}
 		container.StartupProbe = t.newStartupProbe(port, t.StartupProbe)
 	}
@@ -181,6 +183,7 @@ func (t *healthTrait) newLivenessProbe(port *intstr.IntOrString, path string) *c
 			HTTPGet: &corev1.HTTPGetAction{
 				Path:   path,
 				Scheme: t.getLivenessScheme(),
+				Port:   *t.getLivenessPort(port),
 			},
 		},
 		InitialDelaySeconds: t.LivenessInitialDelay,
@@ -190,10 +193,6 @@ func (t *healthTrait) newLivenessProbe(port *intstr.IntOrString, path string) *c
 		FailureThreshold:    t.LivenessFailureThreshold,
 	}
 
-	if port != nil {
-		p.ProbeHandler.HTTPGet.Port = *port
-	}
-
 	return &p
 }
 
@@ -203,6 +202,7 @@ func (t *healthTrait) newReadinessProbe(port *intstr.IntOrString, path string) *
 			HTTPGet: &corev1.HTTPGetAction{
 				Path:   path,
 				Scheme: t.getReadinessScheme(),
+				Port:   *t.getReadinessPort(port),
 			},
 		},
 		InitialDelaySeconds: t.ReadinessInitialDelay,
@@ -212,10 +212,6 @@ func (t *healthTrait) newReadinessProbe(port *intstr.IntOrString, path string) *
 		FailureThreshold:    t.ReadinessFailureThreshold,
 	}
 
-	if port != nil {
-		p.ProbeHandler.HTTPGet.Port = *port
-	}
-
 	return &p
 }
 
@@ -225,6 +221,7 @@ func (t *healthTrait) newStartupProbe(port *intstr.IntOrString, path string) *co
 			HTTPGet: &corev1.HTTPGetAction{
 				Path:   path,
 				Scheme: t.getStartupScheme(),
+				Port:   *t.getStartupPort(port),
 			},
 		},
 		InitialDelaySeconds: t.StartupInitialDelay,
@@ -234,9 +231,35 @@ func (t *healthTrait) newStartupProbe(port *intstr.IntOrString, path string) *co
 		FailureThreshold:    t.StartupFailureThreshold,
 	}
 
-	if port != nil {
-		p.ProbeHandler.HTTPGet.Port = *port
-	}
-
 	return &p
 }
+
+func (t *healthTrait) getLivenessPort(port *intstr.IntOrString) *intstr.IntOrString {
+	if t.LivenessPort != 0 {
+		livenessPort := intstr.FromInt32(t.LivenessPort)
+
+		return &livenessPort
+	}
+
+	return port
+}
+
+func (t *healthTrait) getReadinessPort(port *intstr.IntOrString) *intstr.IntOrString {
+	if t.ReadinessPort != 0 {
+		readinessPort := intstr.FromInt32(t.ReadinessPort)
+
+		return &readinessPort
+	}
+
+	return port
+}
+
+func (t *healthTrait) getStartupPort(port *intstr.IntOrString) *intstr.IntOrString {
+	if t.StartupPort != 0 {
+		startupPort := intstr.FromInt32(t.StartupPort)
+
+		return &startupPort
+	}
+
+	return port
+}
