@@ -21,19 +21,15 @@ import (
 	"errors"
 	"sort"
 
-	"k8s.io/utils/pointer"
-
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/util"
-	"github.com/apache/camel-k/v2/pkg/util/dsl"
+	"k8s.io/utils/ptr"
 )
 
 const (
 	initTraitID    = "init"
 	initTraitOrder = 1
-
-	flowsInternalSourceName = "camel-k-embedded-flow.yaml"
 )
 
 type initTrait struct {
@@ -48,7 +44,7 @@ func NewInitTrait() Trait {
 }
 
 func (t *initTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
-	if !pointer.BoolDeref(t.Enabled, true) {
+	if !ptr.Deref(t.Enabled, true) {
 		return false, nil, errors.New("trait init cannot be disabled")
 	}
 
@@ -58,13 +54,13 @@ func (t *initTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 func (t *initTrait) Apply(e *Environment) error {
 	// Flows need to be turned into a generated source
 	if len(e.Integration.Spec.Flows) > 0 {
-		content, err := dsl.ToYamlDSL(e.Integration.Spec.Flows)
+		content, err := v1.ToYamlDSL(e.Integration.Spec.Flows)
 		if err != nil {
 			return err
 		}
 		e.Integration.Status.AddOrReplaceGeneratedSources(v1.SourceSpec{
 			DataSpec: v1.DataSpec{
-				Name:    flowsInternalSourceName,
+				Name:    v1.IntegrationFlowEmbeddedSourceName,
 				Content: string(content),
 			},
 		})
