@@ -68,6 +68,7 @@ func (t *jolokiaTrait) Configure(e *Environment) (bool, *TraitCondition, error)
 func (t *jolokiaTrait) Apply(e *Environment) error {
 	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
 		util.StringSliceUniqueAdd(&e.Integration.Status.Capabilities, v1.CapabilityJolokia)
+
 		return nil
 	}
 
@@ -79,6 +80,7 @@ func (t *jolokiaTrait) Apply(e *Environment) error {
 			v1.IntegrationConditionContainerNotAvailableReason,
 			"",
 		)
+
 		return nil
 	}
 
@@ -103,6 +105,7 @@ func (t *jolokiaTrait) Apply(e *Environment) error {
 	for _, ar := range e.IntegrationKit.Status.Artifacts {
 		if strings.HasPrefix(ar.ID, "org.jolokia.jolokia-agent-jvm") || strings.HasPrefix(ar.ID, "org.jolokia.jolokia-jvm") {
 			jolokiaFilepath = ar.Target
+
 			break
 		}
 	}
@@ -187,7 +190,7 @@ func (t *jolokiaTrait) addToJolokiaOptions(options map[string]string) {
 	if t.Password != nil {
 		options["password"] = *t.Password
 	}
-	options["port"] = fmt.Sprintf("%v", t.getPort())
+	options["port"] = strconv.Itoa(int(t.getPort()))
 	if t.Protocol != nil {
 		options["protocol"] = *t.Protocol
 	}
