@@ -20,6 +20,7 @@ package trait
 import (
 	"errors"
 	"fmt"
+	"net/url"
 	"path/filepath"
 	"sort"
 	"strconv"
@@ -39,6 +40,7 @@ import (
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/digest"
 	"github.com/apache/camel-k/v2/pkg/util/dsl"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 )
 
 const (
@@ -51,8 +53,6 @@ const (
 	kameletMountPointAnnotation = "camel.apache.org/kamelet.mount-point"
 )
 
-var kameletVersionProperty = fmt.Sprintf("?%s=", v1.KameletVersionProperty)
-
 type kameletsTrait struct {
 	BaseTrait
 	traitv1.KameletsTrait `property:",squash"`
@@ -78,6 +78,7 @@ func (t *kameletsTrait) Configure(e *Environment) (bool, *TraitCondition, error)
 		var kamelets []string
 		_, err := e.ConsumeMeta(false, func(meta metadata.IntegrationMetadata) bool {
 			util.StringSliceUniqueConcat(&kamelets, meta.Kamelets)
+
 			return true
 		})
 		if err != nil {
@@ -89,7 +90,7 @@ func (t *kameletsTrait) Configure(e *Environment) (bool, *TraitCondition, error)
 		}
 	}
 
-	return len(t.getKameletKeys(false)) > 0, nil, nil
+	return len(t.getKameletKeys()) > 0, nil, nil
 }
 
 func (t *kameletsTrait) Apply(e *Environment) error {
@@ -98,23 +99,28 @@ func (t *kameletsTrait) Apply(e *Environment) error {
 			return err
 		}
 	}
+
 	return nil
 }
 
 // collectKamelets load a Kamelet specification setting the specific version specification.
 func (t *kameletsTrait) collectKamelets(e *Environment) (map[string]*v1.Kamelet, error) {
-	repo, err := repository.NewForPlatform(e.Ctx, e.Client, e.Platform, e.Integration.Namespace, platform.GetOperatorNamespace())
+	namespaces, err := t.calculateNamespaces(e, e.Integration.Namespace, platform.GetOperatorNamespace())
+	if err != nil {
+		return nil, err
+	}
+	repo, err := repository.NewForPlatform(e.Ctx, e.Client, e.Platform, namespaces...)
 	if err != nil {
 		return nil, err
 	}
 
 	kamelets := make(map[string]*v1.Kamelet)
-	missingKamelets := make([]string, 0)
-	availableKamelets := make([]string, 0)
-	bundledKamelets := make([]string, 0)
+	var missingKamelets []string
+	var availableKamelets []string
+	var bundledKamelets []string
 
 	for _, kml := range strings.Split(t.List, ",") {
-		name := getKameletKey(kml, false)
+		name := getKameletKey(kml)
 		if !v1.ValidKameletName(name) {
 			// Skip kamelet sink and source id
 			continue
@@ -125,6 +131,7 @@ func (t *kameletsTrait) collectKamelets(e *Environment) (map[string]*v1.Kamelet,
 		}
 		if kamelet == nil {
 			missingKamelets = append(missingKamelets, name)
+
 			continue
 		} else {
 			availableKamelets = append(availableKamelets, name)
@@ -133,7 +140,11 @@ func (t *kameletsTrait) collectKamelets(e *Environment) (map[string]*v1.Kamelet,
 			bundledKamelets = append(bundledKamelets, name)
 		}
 		// We control which version to use (if any is specified)
-		clonedKamelet, err := kamelet.CloneWithVersion(getKameletVersion(kml))
+		version, err := getKameletVersion(kml)
+		if err != nil {
+			return nil, fmt.Errorf("could not parse kamelet version: %w", err)
+		}
+		clonedKamelet, err := kamelet.CloneWithVersion(version)
 		if err != nil {
 			return nil, err
 		}
@@ -144,29 +155,11 @@ func (t *kameletsTrait) collectKamelets(e *Environment) (map[string]*v1.Kamelet,
 	sort.Strings(missingKamelets)
 	sort.Strings(bundledKamelets)
 
-	if len(missingKamelets) > 0 {
-		message := fmt.Sprintf("kamelets [%s] not found in %s repositories",
-			strings.Join(missingKamelets, ","),
-			repo.String())
-		e.Integration.Status.SetCondition(
-			v1.IntegrationConditionKameletsAvailable,
-			corev1.ConditionFalse,
-			v1.IntegrationConditionKameletsAvailableReason,
-			message,
-		)
-
-		return nil, errors.New(message)
-	}
-
-	// TODO:
 	// We list the Kamelets coming from a bundle. We want to warn the user
-	// that in the future we'll use the specification coming from the dependency runtime
-	// instead of using the one installed in the cluster.
-	// It may be a good idea in the future to let the user specify the catalog dependency to use
-	// in order to override the one coming from Apache catalog
+	// that in the future we won't use any longer bundled Kamelets.
 	if len(bundledKamelets) > 0 {
-		message := fmt.Sprintf("using bundled kamelets [%s]: make sure the Kamelet specifications is compatible with this Integration runtime."+
-			" This feature is deprecated as in the future we will use directly the specification coming from the Kamelet catalog dependency jar.",
+		message := fmt.Sprintf("using bundled Kamelets [%s]: make sure the Kamelet specifications is compatible with this Integration runtime."+
+			" This feature is deprecated as in the future we will use directly the Kamelets provided in the dependencies provided.",
 			strings.Join(bundledKamelets, ","))
 		e.Integration.Status.SetCondition(
 			v1.IntegrationConditionType("KameletsDeprecationNotice"),
@@ -176,18 +169,97 @@ func (t *kameletsTrait) collectKamelets(e *Environment) (map[string]*v1.Kamelet,
 		)
 	}
 
+	kameletsAvailabilityMessage := ""
+	cond := corev1.ConditionTrue
+	if len(missingKamelets) > 0 {
+		kameletsAvailabilityMessage = fmt.Sprintf("Kamelets [%s] not found in cluster. "+
+			"Make sure to include the Kamelets dependency in the Integration.",
+			strings.Join(missingKamelets, ","))
+		cond = corev1.ConditionUnknown
+	}
+	if len(availableKamelets) > 0 {
+		if kameletsAvailabilityMessage != "" {
+			kameletsAvailabilityMessage += "; "
+		}
+		kameletsAvailabilityMessage += fmt.Sprintf("Kamelets [%s] found in cluster", strings.Join(availableKamelets, ","))
+	}
 	e.Integration.Status.SetCondition(
 		v1.IntegrationConditionKameletsAvailable,
-		corev1.ConditionTrue,
+		cond,
 		v1.IntegrationConditionKameletsAvailableReason,
-		fmt.Sprintf("kamelets [%s] found in %s repositories", strings.Join(availableKamelets, ","), repo.String()),
+		kameletsAvailabilityMessage,
 	)
 
 	return kamelets, nil
 }
 
+// calculateNamespaces is in charge to scan the kamelets specification and provide a list of
+// namespaces where to look for Kamelets.
+func (t *kameletsTrait) calculateNamespaces(e *Environment, defaultNamespaces ...string) ([]string, error) {
+	namespaces, err := calculateNamespaces(strings.Split(t.List, ","))
+	if err != nil {
+		return namespaces, err
+	}
+	if len(namespaces) > 0 {
+		if e.Integration.Spec.ServiceAccountName == "" {
+			return nil, errors.New("you must to use an authorized ServiceAccount to access cross-namespace resources kamelets. " +
+				"Set it in the Integration spec accordingly")
+		}
+		// verify an SA exists and it is authorized for Kamelets in that namespace
+		for _, ns := range namespaces {
+			ok, err := kubernetes.CheckServiceAccountPermission(
+				e.Ctx,
+				e.Client,
+				fmt.Sprintf("system:serviceaccount:%s:%s", e.Integration.Namespace, e.Integration.Spec.ServiceAccountName),
+				v1.SchemeGroupVersion.Group,
+				"kamelets",
+				ns,
+				"get",
+			)
+			if err != nil {
+				return nil, err
+			}
+			if !ok {
+				return nil, fmt.Errorf("cross-namespace Integration reference authorization denied for the ServiceAccount %s and resources kamelets",
+					e.Integration.Spec.ServiceAccountName)
+			}
+		}
+	}
+
+	// Also append the default namespaces
+	namespaces = append(namespaces, defaultNamespaces...)
+
+	return namespaces, nil
+}
+
+func calculateNamespaces(kamelets []string) ([]string, error) {
+	var namespaces []string
+	for _, kml := range kamelets {
+		ns, err := getKameletNamespace(kml)
+		if err != nil {
+			return nil, fmt.Errorf("could not parse kamelet namespace: %w", err)
+		}
+		if ns != "" {
+			addNs := true
+		loop:
+			for _, addedNs := range namespaces {
+				if addedNs == ns {
+					addNs = false
+
+					break loop
+				}
+			}
+			if addNs {
+				namespaces = append(namespaces, ns)
+			}
+		}
+	}
+
+	return namespaces, nil
+}
+
 func (t *kameletsTrait) addKamelets(e *Environment) error {
-	if len(t.getKameletKeys(false)) == 0 {
+	if len(t.getKameletKeys()) == 0 {
 		return nil
 	}
 	kamelets, err := t.collectKamelets(e)
@@ -217,9 +289,9 @@ func (t *kameletsTrait) addKamelets(e *Environment) error {
 		cm.Annotations[kameletMountPointAnnotation] = kameletMountPoint
 		e.Resources.Add(cm)
 		if e.ApplicationProperties[KameletLocationProperty] == "" {
-			e.ApplicationProperties[KameletLocationProperty] = fmt.Sprintf("file:%s", kameletMountPoint)
+			e.ApplicationProperties[KameletLocationProperty] = "file:" + kameletMountPoint
 		} else {
-			e.ApplicationProperties[KameletLocationProperty] += fmt.Sprintf(",file:%s", kameletMountPoint)
+			e.ApplicationProperties[KameletLocationProperty] += ",file:" + kameletMountPoint
 		}
 	}
 	e.ApplicationProperties[KameletLocationProperty] += ",classpath:/kamelets"
@@ -244,7 +316,7 @@ func (t *kameletsTrait) addKameletAsSource(e *Environment, kamelet *v1.Kamelet)
 		}
 		flowSource := v1.SourceSpec{
 			DataSpec: v1.DataSpec{
-				Name:    fmt.Sprintf("%s.yaml", kamelet.Name),
+				Name:    kamelet.Name + ".yaml",
 				Content: string(flowData),
 			},
 			Language: v1.LanguageYaml,
@@ -280,15 +352,16 @@ func (t *kameletsTrait) addKameletAsSource(e *Environment, kamelet *v1.Kamelet)
 	return nil
 }
 
-func (t *kameletsTrait) getKameletKeys(withVersion bool) []string {
+func (t *kameletsTrait) getKameletKeys() []string {
 	answer := make([]string, 0)
 	for _, item := range strings.Split(t.List, ",") {
-		i := getKameletKey(item, withVersion)
+		i := getKameletKey(item)
 		if i != "" && v1.ValidKameletName(i) {
 			util.StringSliceUniqueAdd(&answer, i)
 		}
 	}
 	sort.Strings(answer)
+
 	return answer
 }
 
@@ -300,28 +373,37 @@ func (t *kameletsTrait) getMountPoint() string {
 	return t.MountPoint
 }
 
-func getKameletKey(item string, withVersion bool) string {
-	i := strings.Trim(item, " \t\"")
-	if strings.Contains(i, "/") {
-		i = strings.SplitN(i, "/", 2)[0]
+// getKameletKey remove any params from the kamelet, eg my-kamelet/abc?param1=1 will return the uri path filtered (my-kamelet).
+func getKameletKey(item string) string {
+	parsedURL, err := url.Parse(item)
+	if err != nil {
+		return ""
 	}
-	if strings.Contains(i, kameletVersionProperty) {
-		versionedKamelet := strings.SplitN(i, kameletVersionProperty, 2)
-		if withVersion {
-			i = fmt.Sprintf("%s-%s", versionedKamelet[0], versionedKamelet[1])
-		} else {
-			i = versionedKamelet[0]
-		}
+	parts := strings.Split(parsedURL.Path, "/")
+	if len(parts) > 0 {
+		return parts[0]
 	}
-	return i
+
+	return ""
 }
 
-func getKameletVersion(item string) string {
-	if strings.Contains(item, fmt.Sprintf("?%s=", v1.KameletVersionProperty)) {
-		versionedKamelet := strings.SplitN(item, kameletVersionProperty, 2)
-		return versionedKamelet[1]
+func getKameletVersion(item string) (string, error) {
+	return getKameletParam(item, v1.KameletVersionProperty)
+}
+
+func getKameletNamespace(item string) (string, error) {
+	return getKameletParam(item, v1.KameletNamespaceProperty)
+}
+
+func getKameletParam(uri, param string) (string, error) {
+	parsedURL, err := url.Parse(uri)
+	if err != nil {
+		return "", err
 	}
-	return ""
+
+	queryParams := parsedURL.Query()
+
+	return queryParams.Get(param), nil
 }
 
 func integrationSourceFromKameletSource(e *Environment, kamelet *v1.Kamelet, source v1.SourceSpec, name string) (v1.SourceSpec, error) {
@@ -333,7 +415,7 @@ func integrationSourceFromKameletSource(e *Environment, kamelet *v1.Kamelet, sou
 
 	source.FromKamelet = true
 
-	if source.DataSpec.ContentRef != "" {
+	if source.ContentRef != "" {
 		return source, nil
 	}
 
@@ -350,6 +432,7 @@ func integrationSourceFromKameletSource(e *Environment, kamelet *v1.Kamelet, sou
 	target.Content = ""
 	target.ContentRef = name
 	target.ContentKey = contentKey
+
 	return *target, nil
 }
 
