@@ -68,8 +68,7 @@ func TestConfigurationWithKamelets(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"c0", "c1", "c2", "c3", "complex-.-.-1a", "complex-.-.-1b", "complex-.-.-1c"}, trait.getKameletKeys(false))
-	assert.Equal(t, []string{"c0", "c1", "c2", "c3-v1", "complex-.-.-1a", "complex-.-.-1b", "complex-.-.-1c"}, trait.getKameletKeys(true))
+	assert.Equal(t, []string{"c0", "c1", "c2", "c3", "complex-.-.-1a", "complex-.-.-1b", "complex-.-.-1c"}, trait.getKameletKeys())
 }
 
 func TestKameletLookup(t *testing.T) {
@@ -101,7 +100,7 @@ func TestKameletLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
@@ -139,10 +138,10 @@ func TestKameletSecondarySourcesLookup(t *testing.T) {
 				Sources: []v1.SourceSpec{
 					{
 						DataSpec: v1.DataSpec{
-							Name:    "support.groovy",
+							Name:    "support.java",
 							Content: "from('xxx:xxx').('to:log:info')",
 						},
-						Language: v1.LanguageGroovy,
+						Language: v1.LanguageJavaSource,
 					},
 				},
 			},
@@ -152,7 +151,7 @@ func TestKameletSecondarySourcesLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
@@ -170,7 +169,7 @@ func TestKameletSecondarySourcesLookup(t *testing.T) {
 	assert.Equal(t, "content", flowSource.ContentKey)
 
 	supportSource := environment.Integration.Status.GeneratedSources[1]
-	assert.Equal(t, "support.groovy", supportSource.Name)
+	assert.Equal(t, "support.java", supportSource.Name)
 	assert.Equal(t, "", string(supportSource.Type))
 	assert.Equal(t, "it-kamelet-timer-000", supportSource.ContentRef)
 	assert.Equal(t, "content", supportSource.ContentKey)
@@ -192,8 +191,8 @@ func TestNonYAMLKameletLookup(t *testing.T) {
 				Sources: []v1.SourceSpec{
 					{
 						DataSpec: v1.DataSpec{
-							Name:    "mykamelet.groovy",
-							Content: `from("timer").to("log:info")`,
+							Name:    "mykamelet.java",
+							Content: `from("timer").to("log:info");`,
 						},
 						Type: v1.SourceTypeTemplate,
 					},
@@ -205,7 +204,7 @@ func TestNonYAMLKameletLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
@@ -216,7 +215,7 @@ func TestNonYAMLKameletLookup(t *testing.T) {
 
 	assert.Len(t, environment.Integration.Status.GeneratedSources, 1)
 	source := environment.Integration.Status.GeneratedSources[0]
-	assert.Equal(t, "timer.groovy", source.Name)
+	assert.Equal(t, "timer.java", source.Name)
 	assert.Equal(t, "template", string(source.Type))
 }
 
@@ -248,10 +247,10 @@ func TestMultipleKamelets(t *testing.T) {
 					Sources: []v1.SourceSpec{
 						{
 							DataSpec: v1.DataSpec{
-								Name:    "support.groovy",
+								Name:    "support.java",
 								Content: "from('xxx:xxx').('to:log:info')",
 							},
-							Language: v1.LanguageGroovy,
+							Language: v1.LanguageJavaSource,
 						},
 					},
 					Dependencies: []string{
@@ -312,8 +311,7 @@ func TestMultipleKamelets(t *testing.T) {
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
 	assert.Equal(t, "logger,timer?kameletVersion=v1", trait.List)
-	assert.Equal(t, []string{"logger", "timer"}, trait.getKameletKeys(false))
-	assert.Equal(t, []string{"logger", "timer-v1"}, trait.getKameletKeys(true))
+	assert.Equal(t, []string{"logger", "timer"}, trait.getKameletKeys())
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
@@ -331,11 +329,11 @@ func TestMultipleKamelets(t *testing.T) {
 
 	expectedFlowSourceTimerV1 := v1.SourceSpec{
 		DataSpec: v1.DataSpec{
-			Name:       "support.groovy",
+			Name:       "support.java",
 			ContentRef: "it-kamelet-timer-000",
 			ContentKey: "content",
 		},
-		Language:    v1.LanguageGroovy,
+		Language:    v1.LanguageJavaSource,
 		FromKamelet: true,
 	}
 
@@ -409,7 +407,7 @@ func TestKameletConfigLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 }
 
 func TestKameletNamedConfigLookup(t *testing.T) {
@@ -467,7 +465,7 @@ func TestKameletNamedConfigLookup(t *testing.T) {
 	require.NoError(t, err)
 	assert.True(t, enabled)
 	assert.Nil(t, condition)
-	assert.Equal(t, []string{"timer"}, trait.getKameletKeys(false))
+	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 }
 
 func TestKameletConditionFalse(t *testing.T) {
@@ -501,13 +499,13 @@ func TestKameletConditionFalse(t *testing.T) {
 	assert.Nil(t, condition)
 
 	err = trait.Apply(environment)
-	require.Error(t, err)
+	require.NoError(t, err)
 	assert.Len(t, environment.Integration.Status.Conditions, 1)
 
 	cond := environment.Integration.Status.GetCondition(v1.IntegrationConditionKameletsAvailable)
-	assert.Equal(t, corev1.ConditionFalse, cond.Status)
+	assert.Equal(t, corev1.ConditionUnknown, cond.Status)
 	assert.Equal(t, v1.IntegrationConditionKameletsAvailableReason, cond.Reason)
-	assert.Contains(t, cond.Message, "kamelets [none] not found")
+	assert.Contains(t, cond.Message, "Kamelets [none] not found")
 }
 
 func TestKameletConditionTrue(t *testing.T) {
@@ -753,3 +751,160 @@ func TestKameletAuto(t *testing.T) {
 	)
 	assert.Equal(t, "false", environment.ApplicationProperties[KameletErrorHandler])
 }
+
+func TestKameletVersionParameter(t *testing.T) {
+	v1, err := getKameletVersion("my-kamelet?kameletVersion=v2")
+	require.NoError(t, err)
+	assert.Equal(t, "v2", v1)
+	v2, err := getKameletVersion("my-kamelet?prop1=1&kameletVersion=v2")
+	require.NoError(t, err)
+	assert.Equal(t, "v2", v2)
+	v3, err := getKameletVersion("my-kamelet")
+	require.NoError(t, err)
+	assert.Equal(t, "", v3)
+}
+
+func TestKameletNamespaceParameter(t *testing.T) {
+	v2, err := getKameletNamespace("my-kamelet?prop1=1&kameletNamespace=my-ns")
+	require.NoError(t, err)
+	assert.Equal(t, "my-ns", v2)
+}
+
+func TestCalculateKameletNamespaces(t *testing.T) {
+	namespaces, err := calculateNamespaces(
+		[]string{"my-kamelet", "my-kamelet?kameletNamespace=ns1", "my-kamelet?kameletVersion=v2&kameletNamespace=ns2"},
+	)
+	require.NoError(t, err)
+	assert.Len(t, namespaces, 2)
+	assert.Contains(t, namespaces, "ns1")
+	assert.Contains(t, namespaces, "ns2")
+}
+
+func TestKameletMultiNamespace(t *testing.T) {
+	flow := `
+- from:
+    uri: kamelet:timer
+    steps:
+    - to: kamelet:extra?kameletNamespace=ns1
+`
+	trait, environment := createKameletsTestEnvironment(
+		flow,
+		&v1.Kamelet{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "default",
+				Name:      "timer",
+			},
+			Spec: v1.KameletSpec{
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
+			},
+		},
+		&v1.Kamelet{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "ns1",
+				Name:      "extra",
+			},
+			Spec: v1.KameletSpec{
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
+			},
+		})
+
+	enabled, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.True(t, enabled)
+	assert.Nil(t, condition)
+
+	// Must fail, no ServiceAccount
+	err = trait.Apply(environment)
+	require.Error(t, err)
+	assert.Equal(t, "you must to use an authorized ServiceAccount to access cross-namespace resources kamelets. "+
+		"Set it in the Integration spec accordingly", err.Error())
+	// Must fail, unauthorized ServiceAccount
+	environment.Integration.Spec.ServiceAccountName = "unauth-sa"
+	err = trait.Apply(environment)
+	require.Error(t, err)
+	assert.Equal(t, "cross-namespace Integration reference authorization denied for the ServiceAccount unauth-sa "+
+		"and resources kamelets", err.Error())
+	// Now we should good to go
+	environment.Integration.Namespace = "default"
+	environment.Integration.Spec.ServiceAccountName = "cross-ns-sa"
+	err = trait.Apply(environment)
+	require.NoError(t, err)
+	assert.Equal(t, "extra?kameletNamespace=ns1,timer", trait.List)
+	assert.Equal(t,
+		corev1.ConditionTrue,
+		environment.Integration.Status.GetCondition(v1.IntegrationConditionKameletsAvailable).Status)
+	assert.Contains(t,
+		environment.Integration.Status.GetCondition(v1.IntegrationConditionKameletsAvailable).Message,
+		"Kamelets [extra,timer] found in cluster")
+}
+
+func TestKameletMultiNamespaceMissing(t *testing.T) {
+	flow := `
+- from:
+    uri: kamelet:timer
+    steps:
+    - to: kamelet:missing?kameletNamespace=ns1
+`
+	trait, environment := createKameletsTestEnvironment(
+		flow,
+		&v1.Kamelet{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "default",
+				Name:      "timer",
+			},
+			Spec: v1.KameletSpec{
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
+			},
+		},
+		&v1.Kamelet{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "another-namespace",
+				Name:      "missing",
+			},
+			Spec: v1.KameletSpec{
+				KameletSpecBase: v1.KameletSpecBase{
+					Template: templateOrFail(map[string]interface{}{
+						"from": map[string]interface{}{
+							"uri": "timer:tick",
+						},
+					}),
+				},
+			},
+		})
+
+	// Cross namespaces authorized user
+	environment.Integration.Namespace = "default"
+	environment.Integration.Spec.ServiceAccountName = "cross-ns-sa"
+	enabled, condition, err := trait.Configure(environment)
+	require.NoError(t, err)
+	assert.True(t, enabled)
+	assert.Nil(t, condition)
+	assert.Equal(t, "missing?kameletNamespace=ns1,timer", trait.List)
+
+	err = trait.Apply(environment)
+	require.NoError(t, err)
+	assert.Equal(t,
+		corev1.ConditionUnknown,
+		environment.Integration.Status.GetCondition(v1.IntegrationConditionKameletsAvailable).Status)
+	assert.Contains(t,
+		environment.Integration.Status.GetCondition(v1.IntegrationConditionKameletsAvailable).Message,
+		"Kamelets [missing] not found in cluster")
+}
