@@ -30,9 +30,9 @@ import (
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+	"github.com/apache/camel-k/v2/pkg/internal"
 	"github.com/apache/camel-k/v2/pkg/util/camel"
 	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
-	"github.com/apache/camel-k/v2/pkg/util/test"
 )
 
 func TestDefaultPodKubernetesSecurityContextInitializationPhase(t *testing.T) {
@@ -149,7 +149,7 @@ func TestUserPodSecurityContext(t *testing.T) {
 func createPodSettingContextEnvironment(t *testing.T, profile v1.TraitProfile) *Environment {
 	catalog, err := camel.DefaultCatalog()
 	require.NoError(t, err)
-	client, _ := test.NewFakeClient()
+	client, _ := internal.NewFakeClient()
 	traitCatalog := NewCatalog(nil)
 	environment := Environment{
 		CamelCatalog: catalog,
@@ -208,11 +208,11 @@ func createOpenshiftPodSettingContextEnvironment(t *testing.T, profile v1.TraitP
 		},
 	}
 
-	client, _ := test.NewFakeClient(constrainedIntNamespace)
+	client, _ := internal.NewFakeClient(constrainedIntNamespace)
 	traitCatalog := NewCatalog(nil)
 
 	// enable openshift
-	fakeClient := client.(*test.FakeClient) //nolint
+	fakeClient := client.(*internal.FakeClient) //nolint
 	fakeClient.EnableOpenshiftDiscovery()
 	catalog, err := camel.DefaultCatalog()
 	require.NoError(t, err)
