@@ -46,6 +46,7 @@ func NewCatalog(c client.Client) *Catalog {
 		if traitList[i].Order() != traitList[j].Order() {
 			return traitList[i].Order() < traitList[j].Order()
 		}
+
 		return string(traitList[i].ID()) < string(traitList[j].ID())
 	})
 
@@ -59,6 +60,7 @@ func NewCatalog(c client.Client) *Catalog {
 			t.InjectClient(c)
 		}
 	}
+
 	return &catalog
 }
 
@@ -70,6 +72,7 @@ func (c *Catalog) AllTraits() []Trait {
 // so care must be taken while changing the lists order.
 func (c *Catalog) traitsFor(environment *Environment) []Trait {
 	profile := environment.DetermineProfile()
+
 	return c.TraitsForProfile(profile)
 }
 
@@ -84,6 +87,7 @@ func (c *Catalog) TraitsForProfile(profile v1.TraitProfile) []Trait {
 			res = append(res, t)
 		}
 	}
+
 	return res
 }
 
@@ -159,13 +163,7 @@ func (c *Catalog) executedTraitCondition(executedTrait []Trait) (*TraitCondition
 			return nil, traits, err
 		}
 		if len(traitIDMap) > 0 {
-			if isAddon(string(trait.ID())) {
-				traitMap["addons"] = map[string]interface{}{
-					string(trait.ID()): traitIDMap,
-				}
-			} else {
-				traitMap[string(trait.ID())] = traitIDMap
-			}
+			traitMap[string(trait.ID())] = traitIDMap
 		}
 
 		traitIds = append(traitIds, string(trait.ID()))
@@ -179,20 +177,12 @@ func (c *Catalog) executedTraitCondition(executedTrait []Trait) (*TraitCondition
 		return nil, traits, err
 	}
 
-	message := fmt.Sprintf("Applied traits: %s", strings.Join(traitIds, ","))
+	message := "Applied traits: " + strings.Join(traitIds, ",")
 	c.L.Debug(message)
 
 	return NewIntegrationCondition("", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, TraitConfigurationReason, message), traits, nil
 }
 
-// Deprecated: remove this check when we include the addons traits into regular traits
-// see https://github.com/apache/camel-k/issues/5787
-// isAddon returns true if the trait is an addon.
-func isAddon(id string) bool {
-	return id == "master" || id == "keda" || id == "3scale" || id == "tracing" ||
-		id == "aws-secrets-manager" || id == "azure-key-vault" || id == "gcp-secret-manager" || id == "hashicorp-vault"
-}
-
 // GetTrait returns the trait with the given ID.
 func (c *Catalog) GetTrait(id string) Trait {
 	for _, t := range c.AllTraits() {
@@ -200,6 +190,7 @@ func (c *Catalog) GetTrait(id string) Trait {
 			return t
 		}
 	}
+
 	return nil
 }
 
