@@ -75,23 +75,10 @@ func (c *Catalog) configureTraits(traits interface{}) error {
 	}
 
 	for id, trait := range traitMap {
-		if id == "addons" {
-			// Handle addons later so that the configurations on the new API
-			// take precedence over the legacy addon configurations
-			continue
-		}
 		if err := c.configureTrait(id, trait); err != nil {
 			return err
 		}
 	}
-	// Addons
-	for id, trait := range traitMap["addons"] {
-		if addons, ok := trait.(map[string]interface{}); ok {
-			if err := c.configureTrait(id, addons); err != nil {
-				return err
-			}
-		}
-	}
 
 	return nil
 }
@@ -155,6 +142,7 @@ func (c *Catalog) configureTraitsFromAnnotations(annotations map[string]string)
 		}
 		current[prop] = v
 	}
+
 	return c.configureFromOptions(options)
 }
 
@@ -169,6 +157,7 @@ func (c *Catalog) configureFromOptions(traits map[string]map[string]interface{})
 			}
 		}
 	}
+
 	return nil
 }
 
@@ -184,9 +173,11 @@ func configureTrait(id string, config map[string]interface{}, trait interface{})
 				if err := json.Unmarshal([]byte(v), &value); err != nil {
 					return nil, fmt.Errorf("could not decode JSON array for configuring trait property: %w", err)
 				}
+
 				return value, nil
 			}
 		}
+
 		return data, nil
 	}
 
