@@ -21,9 +21,10 @@ import (
 	"errors"
 	"fmt"
 	"sort"
+	"strings"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 	"k8s.io/utils/ptr"
 )
 
@@ -35,6 +36,7 @@ func RegisterBindingProvider(bp BindingProvider) {
 	sort.Slice(bindingProviders, func(i, j int) bool {
 		bi := bindingProviders[i]
 		bj := bindingProviders[j]
+
 		return (bi.Order() < bj.Order()) ||
 			(bi.Order() == bj.Order() && bi.ID() < bj.ID())
 	})
@@ -61,8 +63,9 @@ func Translate(ctx BindingContext, endpointCtx EndpointContext, endpoint v1.Endp
 		errorMessage = fmt.Sprintf("could not find any suitable binding provider for %s/%s %s in namespace %s. Bindings available: %q",
 			endpoint.Ref.APIVersion, endpoint.Ref.Kind, endpoint.Ref.Name, endpoint.Ref.Namespace, availableBindings)
 	} else if ptr.Deref(endpoint.URI, "") != "" {
-		errorMessage = fmt.Sprintf("could not find any suitable binding provider for %s", *endpoint.URI)
+		errorMessage = "could not find any suitable binding provider for " + *endpoint.URI
 	}
+
 	return nil, errors.New(errorMessage)
 }
 
@@ -73,12 +76,46 @@ func validateEndpoint(ctx BindingContext, e v1.Endpoint) error {
 		return errors.New("cannot use both ref and URI to specify an endpoint: only one of them should be used")
 	}
 	if e.Ref != nil && e.Ref.Namespace != "" && e.Ref.Namespace != ctx.Namespace {
-		// referencing default Kamelets in operator namespace is allowed
-		if e.Ref.Kind == v1.KameletKind && e.Ref.Namespace == platform.GetOperatorNamespace() {
-			return nil
-		}
+		if ok, err := isKnownKnativeResource(e.Ref); ok {
+			if err != nil {
+				return err
+			}
 
-		return errors.New("cross-namespace references are not allowed in Pipe")
+			return errors.New("cross-namespace Pipe references are not allowed for Knative")
+		}
+		// only check this when there is a cross-namespace access
+		return verifyResourceRBAC(ctx, e)
 	}
+
+	return nil
+}
+
+// verifyResourceRBAC verify if the ServiceAccount which is running the Integration has enough
+// privileges to access the resource. We avoid any potential cross-namespace vulnerability access.
+func verifyResourceRBAC(ctx BindingContext, e v1.Endpoint) error {
+	resources := strings.ToLower(e.Ref.Kind) + "s"
+	if ctx.ServiceAccountName == "" {
+		return fmt.Errorf("you must to use an authorized ServiceAccount to access cross-namespace resources %s. "+
+			"Set it in the Pipe spec accordingly", resources)
+	}
+	ok, err := kubernetes.CheckServiceAccountPermission(
+		ctx.Ctx,
+		ctx.Client,
+		fmt.Sprintf("system:serviceaccount:%s:%s", ctx.Namespace, ctx.ServiceAccountName),
+		e.Ref.GroupVersionKind().Group,
+		resources,
+		e.Ref.Namespace,
+		"get",
+	)
+
+	if err != nil {
+		return err
+	}
+
+	if !ok {
+		return fmt.Errorf("cross-namespace Pipe reference authorization denied for the ServiceAccount %s and resources %s",
+			ctx.ServiceAccountName, resources)
+	}
+
 	return nil
 }
