@@ -67,7 +67,7 @@ func ComputeForIntegration(integration *v1.Integration, configmapVersions []stri
 
 	// Integration Kit is relevant
 	if integration.Spec.IntegrationKit != nil {
-		if _, err := hash.Write([]byte(fmt.Sprintf("%s/%s", integration.Spec.IntegrationKit.Namespace, integration.Spec.IntegrationKit.Name))); err != nil {
+		if _, err := fmt.Fprintf(hash, "%s/%s", integration.Spec.IntegrationKit.Namespace, integration.Spec.IntegrationKit.Name); err != nil {
 			return "", err
 		}
 	}
@@ -137,7 +137,7 @@ func ComputeForIntegration(integration *v1.Integration, configmapVersions []stri
 	// Integration traits as annotations
 	for _, k := range sortedTraitAnnotationsKeys(integration) {
 		v := integration.Annotations[k]
-		if _, err := hash.Write([]byte(fmt.Sprintf("%s=%v,", k, v))); err != nil {
+		if _, err := fmt.Fprintf(hash, "%s=%v,", k, v); err != nil {
 			return "", err
 		}
 	}
@@ -162,32 +162,21 @@ func ComputeForIntegration(integration *v1.Integration, configmapVersions []stri
 
 	// Add a letter at the beginning and use URL safe encoding
 	digest := "v" + base64.RawURLEncoding.EncodeToString(hash.Sum(nil))
+
 	return digest, nil
 }
 
-//nolint:nestif
 func computeForTraits(hash hash.Hash, traits v1.Traits) error {
 	specTraitsMap, err := toMap(traits)
 	if err != nil {
 		return err
 	}
 	for _, name := range sortedTraitsMapKeys(specTraitsMap) {
-		if name != "addons" {
-			if err := computeForTrait(hash, name, specTraitsMap[name]); err != nil {
-				return err
-			}
-		} else {
-			// Addons
-			addons := specTraitsMap["addons"]
-			for _, name := range util.SortedMapKeys(addons) {
-				if addon, ok := addons[name].(map[string]interface{}); ok {
-					if err := computeForTrait(hash, name, addon); err != nil {
-						return err
-					}
-				}
-			}
+		if err := computeForTrait(hash, name, specTraitsMap[name]); err != nil {
+			return err
 		}
 	}
+
 	return nil
 }
 
@@ -217,7 +206,7 @@ func computeForTrait(hash hash.Hash, name string, trait map[string]interface{})
 func computeForTraitProps(hash hash.Hash, props map[string]interface{}) error {
 	for _, prop := range util.SortedMapKeys(props) {
 		val := props[prop]
-		if _, err := hash.Write([]byte(fmt.Sprintf("%s=%v,", prop, val))); err != nil {
+		if _, err := fmt.Fprintf(hash, "%s=%v,", prop, val); err != nil {
 			return err
 		}
 	}
@@ -264,35 +253,7 @@ func ComputeForIntegrationKit(kit *v1.IntegrationKit) (string, error) {
 
 	// Add a letter at the beginning and use URL safe encoding
 	digest := "v" + base64.RawURLEncoding.EncodeToString(hash.Sum(nil))
-	return digest, nil
-}
 
-// ComputeForResource returns a digest for the specific resource.
-func ComputeForResource(res v1.DataSpec) (string, error) {
-	hash := sha256.New()
-	// Operator version is relevant
-	if _, err := hash.Write([]byte(defaults.Version)); err != nil {
-		return "", err
-	}
-
-	if _, err := hash.Write([]byte(res.Content)); err != nil {
-		return "", err
-	}
-	if _, err := hash.Write([]byte(res.Name)); err != nil {
-		return "", err
-	}
-	if _, err := hash.Write([]byte(res.ContentKey)); err != nil {
-		return "", err
-	}
-	if _, err := hash.Write([]byte(res.ContentRef)); err != nil {
-		return "", err
-	}
-	if _, err := hash.Write([]byte(strconv.FormatBool(res.Compression))); err != nil {
-		return "", err
-	}
-
-	// Add a letter at the beginning and use URL safe encoding
-	digest := "v" + base64.RawURLEncoding.EncodeToString(hash.Sum(nil))
 	return digest, nil
 }
 
@@ -331,6 +292,7 @@ func ComputeForSource(s v1.SourceSpec) (string, error) {
 
 	// Add a letter at the beginning and use URL safe encoding
 	digest := "v" + base64.RawURLEncoding.EncodeToString(hash.Sum(nil))
+
 	return digest, nil
 }
 
@@ -342,6 +304,7 @@ func sortedTraitsMapKeys(m map[string]map[string]interface{}) []string {
 		i++
 	}
 	sort.Strings(res)
+
 	return res
 }
 
@@ -354,6 +317,7 @@ func sortedTraitAnnotationsKeys(it *v1.Integration) []string {
 		}
 	}
 	sort.Strings(res)
+
 	return res
 }
 
@@ -374,5 +338,6 @@ func ComputeSHA1(elem ...string) (string, error) {
 	if err != nil {
 		return "", err
 	}
+
 	return base64.StdEncoding.EncodeToString(h.Sum(nil)), nil
 }
