@@ -52,6 +52,7 @@ func (c *Command) Do(ctx context.Context) error {
 	cmd.Env = env
 
 	Log.WithValues("MAVEN_OPTS", mavenOptions).Infof("executing: %s", strings.Join(cmd.Args, " "))
+
 	return util.RunAndLog(ctx, cmd, LogHandler, LogHandler)
 }
 
@@ -146,6 +147,7 @@ func (c *Command) optionsFromEnv() ([]string, []string) {
 		for i, e := range env {
 			if strings.HasPrefix(e, "MAVEN_OPTS=") {
 				env[i] = "MAVEN_OPTS=" + mavenOptions
+
 				break
 			}
 		}
@@ -276,6 +278,7 @@ func generateProjectSettings(context Context) error {
 func (c *Command) prepareMavenWrapper(ctx context.Context) error {
 	cmd := exec.CommandContext(ctx, "cp", "--recursive", "/usr/share/maven/mvnw/.", ".")
 	cmd.Dir = c.context.Path
+
 	return util.RunAndLog(ctx, cmd, LogHandler, LogHandler)
 }
 
@@ -295,8 +298,8 @@ func ParseGAV(gav string) (Dependency, error) {
 	}
 	dep.GroupID = res[0]
 	dep.ArtifactID = res[1]
-	switch {
-	case count == 3:
+	switch count {
+	case 3:
 		// gav is: org:artifact:<type:version>
 		numeric := regexp.MustCompile(`\d`)
 		if numeric.MatchString(res[2]) {
@@ -304,16 +307,17 @@ func ParseGAV(gav string) (Dependency, error) {
 		} else {
 			dep.Type = res[2]
 		}
-	case count == 4:
+	case 4:
 		// gav is: org:artifact:type:version
 		dep.Type = res[2]
 		dep.Version = res[3]
-	case count == 5:
+	case 5:
 		// gav is: org:artifact:<type>:<version>:classifier
 		dep.Type = res[2]
 		dep.Version = res[3]
 		dep.Classifier = res[4]
 	}
+
 	return dep, nil
 }
 
@@ -327,13 +331,13 @@ func getMavenContext(args, options []string) string {
 	for _, arg := range args {
 		arg = strings.TrimSpace(arg)
 		if arg != "package" && len(arg) != 0 {
-			mavenContext += fmt.Sprintf("%s\n", arg)
+			mavenContext += arg + "\n"
 		}
 	}
 	for _, opt := range options {
 		opt = strings.TrimSpace(opt)
 		if len(opt) != 0 {
-			mavenContext += fmt.Sprintf("%s\n", opt)
+			mavenContext += opt + "\n"
 		}
 	}
 
