@@ -43,6 +43,7 @@ func Parse(name, content string) ([]Option, error) {
 	for scanner.Scan() {
 		res = append(res, getModelineOptions(scanner.Text(), lang)...)
 	}
+
 	return res, scanner.Err()
 }
 
@@ -75,6 +76,7 @@ func getModelineOptions(line string, lang v1.Language) []Option {
 			res = append(res, opt)
 		}
 	}
+
 	return res
 }
 
@@ -91,12 +93,13 @@ func modelineRegexp(lang v1.Language) *regexp.Regexp {
 
 func inferLanguage(fileName string) v1.Language {
 	for _, l := range v1.Languages {
-		if strings.HasSuffix(fileName, fmt.Sprintf(".%s", string(l))) {
+		if strings.HasSuffix(fileName, "."+string(l)) {
 			return l
 		}
 	}
 	if strings.HasSuffix(fileName, ".yml") {
 		return v1.LanguageYaml
 	}
+
 	return ""
 }
