@@ -43,6 +43,7 @@ func CancelBuild(ctx context.Context, c client.Client, build *buildv1.Build) err
 		return err
 	}
 	*build = *target
+
 	return nil
 }
 
@@ -51,7 +52,6 @@ func WaitForS2iBuildCompletion(ctx context.Context, c client.Client, build *buil
 	key := ctrl.ObjectKeyFromObject(build)
 	for {
 		select {
-
 		case <-ctx.Done():
 			return ctx.Err()
 
@@ -61,14 +61,14 @@ func WaitForS2iBuildCompletion(ctx context.Context, c client.Client, build *buil
 				if apierrors.IsNotFound(err) {
 					continue
 				}
+
 				return err
 			}
 
-			if build.Status.Phase == buildv1.BuildPhaseComplete {
+			switch build.Status.Phase {
+			case buildv1.BuildPhaseComplete:
 				return nil
-			} else if build.Status.Phase == buildv1.BuildPhaseCancelled ||
-				build.Status.Phase == buildv1.BuildPhaseFailed ||
-				build.Status.Phase == buildv1.BuildPhaseError {
+			case buildv1.BuildPhaseCancelled, buildv1.BuildPhaseFailed, buildv1.BuildPhaseError:
 				return errors.New("build failed")
 			}
 		}
@@ -88,6 +88,7 @@ func BuildConfig(ctx context.Context, c client.Client, bc *buildv1.BuildConfig,
 	if err := c.Create(ctx, bc); err != nil {
 		return fmt.Errorf("cannot create build config: %w", err)
 	}
+
 	return nil
 }
 
@@ -104,5 +105,6 @@ func ImageStream(ctx context.Context, c client.Client, is *imagev1.ImageStream,
 	if err := c.Create(ctx, is); err != nil {
 		return fmt.Errorf("cannot create image stream: %w", err)
 	}
+
 	return nil
 }
