@@ -18,10 +18,18 @@ limitations under the License.
 package source
 
 import (
+	"fmt"
+	"regexp"
+
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/util"
 )
 
+var (
+	replaceURIDoubleQuotedFrom  = regexp.MustCompile(`from\s*\(\s*"(?:timer|cron|quartz)[^"]*"\s*\)`)
+	replaceURIDoubleQuotedFromF = regexp.MustCompile(`fromF\s*\(\s*"(?:timer|cron|quartz)[^"]*"\s*\)`)
+)
+
 // JavaScriptInspector inspects Java DSL spec.
 type JavaSourceInspector struct {
 	baseInspector
@@ -43,7 +51,6 @@ func (i JavaSourceInspector) Extract(source v1.SourceSpec, meta *Metadata) error
 	)
 	kameletEips := util.FindAllDistinctStringSubmatch(
 		source.Content,
-		singleQuotedKameletEip,
 		doubleQuotedKameletEip)
 
 	hasRest := restRegexp.MatchString(source.Content)
@@ -55,3 +62,12 @@ func (i JavaSourceInspector) Extract(source v1.SourceSpec, meta *Metadata) error
 func (i JavaSourceInspector) ReplaceFromURI(source *v1.SourceSpec, newFromURI string) (bool, error) {
 	return replaceFromURIDoubleQuotesOnly(source, newFromURI)
 }
+
+func replaceFromURIDoubleQuotesOnly(source *v1.SourceSpec, newFromURI string) (bool, error) {
+	originalContent := source.Content
+
+	source.Content = replaceURIDoubleQuotedFrom.ReplaceAllString(source.Content, fmt.Sprintf(`from("%s")`, newFromURI))
+	source.Content = replaceURIDoubleQuotedFromF.ReplaceAllString(source.Content, fmt.Sprintf(`fromF('%s')`, newFromURI))
+
+	return originalContent != source.Content, nil
+}
