@@ -19,23 +19,23 @@ package source
 
 import (
 	"fmt"
+	"net/url"
 	"regexp"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 )
 
 var kameletNameRegexp = regexp.MustCompile("kamelet:(?://)?([a-z0-9-.]+(/[a-z0-9-.]+)?)(?:$|[^a-z0-9-.].*)")
-var kameletVersionRegexp = regexp.MustCompile(v1.KameletVersionProperty + "=([a-z0-9-.]+)")
 
 func ExtractKamelet(uri string) string {
 	matches := kameletNameRegexp.FindStringSubmatch(uri)
 	if len(matches) > 1 {
-		version := kameletVersionRegexp.FindString(uri)
-		if version != "" {
-			return fmt.Sprintf("%s?%s", matches[1], version)
-		}
-		return matches[1]
+		version := getKameletParam(uri, v1.KameletVersionProperty)
+		namespace := getKameletParam(uri, v1.KameletNamespaceProperty)
+
+		return GetKameletQuerystring(matches[1], version, namespace)
 	}
+
 	return ""
 }
 
@@ -44,3 +44,35 @@ func AddKamelet(meta *Metadata, content string) {
 		meta.Kamelets = append(meta.Kamelets, maybeKamelet)
 	}
 }
+
+// getKameletParam parses the URI and return the query parameter or an empty value if not found.
+func getKameletParam(uri, param string) string {
+	parsedURL, err := url.Parse(uri)
+	if err != nil {
+		return ""
+	}
+
+	queryParams := parsedURL.Query()
+
+	return queryParams.Get(param)
+}
+
+// GetKameletQuerystring returns a kamelet name appended with its version and namespace (if provided).
+func GetKameletQuerystring(name, version, namespace string) string {
+	if version != "" || namespace != "" {
+		var querystring string
+		if version != "" {
+			querystring = v1.KameletVersionProperty + "=" + version
+		}
+		if namespace != "" {
+			if querystring != "" {
+				querystring += "&"
+			}
+			querystring += v1.KameletNamespaceProperty + "=" + namespace
+		}
+
+		return fmt.Sprintf("%s?%s", name, querystring)
+	}
+
+	return name
+}
