@@ -28,7 +28,6 @@ import (
 )
 
 var uriRegexp = regexp.MustCompile(`^[a-z0-9+][a-zA-Z0-9-+]*:.*$`)
-var pathExtractorRegexp = regexp.MustCompile(`^[a-z0-9+][a-zA-Z0-9-+]*:(?://){0,1}[^/?]+/([^?]+)(?:[?].*){0,1}$`)
 var queryExtractorRegexp = `^[^?]+\?(?:|.*[&])%s=([^&]+)(?:[&].*|$)`
 
 // HasCamelURIFormat tells if a given string may belong to a Camel URI, without checking any catalog.
@@ -42,6 +41,7 @@ func GetComponent(uri string) string {
 	if len(parts) <= 1 {
 		return ""
 	}
+
 	return parts[0]
 }
 
@@ -52,22 +52,11 @@ func GetQueryParameter(uri string, param string) string {
 	res, err := url.QueryUnescape(val)
 	if err != nil {
 		log.Error(err, fmt.Sprintf("Invalid character sequence in parameter %q", param))
+
 		return ""
 	}
-	return res
-}
 
-// GetPathSegment returns the path segment of the URI corresponding to the given position (0 based), if present.
-func GetPathSegment(uri string, pos int) string {
-	match := pathExtractorRegexp.FindStringSubmatch(uri)
-	if len(match) > 1 {
-		fullPath := match[1]
-		parts := strings.Split(fullPath, "/")
-		if pos >= 0 && pos < len(parts) {
-			return parts[pos]
-		}
-	}
-	return ""
+	return res
 }
 
 func matchOrEmpty(reg *regexp.Regexp, str string) string {
@@ -75,6 +64,7 @@ func matchOrEmpty(reg *regexp.Regexp, str string) string {
 	if len(match) > 1 {
 		return match[1]
 	}
+
 	return ""
 }
 
@@ -92,5 +82,6 @@ func AppendParameters(uri string, params map[string]string) string {
 		uri += fmt.Sprintf("%s%s=%s", prefix, url.QueryEscape(k), url.QueryEscape(params[k]))
 		prefix = "&"
 	}
+
 	return uri
 }
