@@ -26,21 +26,5 @@ git clone --depth 1 https://github.com/apache/camel-k-runtime.git /tmp/camel-k-r
 ck_runtime_version=$(mvn help:evaluate -Dexpression=project.version -q -DforceStdout -f /tmp/camel-k-runtime/pom.xml)
 echo "INFO: last Camel K runtime version set at $ck_runtime_version"
 sed -i "s/^DEFAULT_RUNTIME_VERSION := .*$/DEFAULT_RUNTIME_VERSION := $ck_runtime_version/" $location/Makefile
-camel_version=$(grep -oPm1 "(?<=<camel-version>)[^<]+" /tmp/camel-k-runtime/pom.xml)
 
-rm -rf /tmp/camel-kamelets
-git clone https://github.com/apache/camel-kamelets.git /tmp/camel-kamelets
-pushd /tmp/camel-kamelets
-echo "INFO: Looking a suitable Kamelet tag for $camel_version camel version"
-kamelets_tag=$(git tag | grep $camel_version | sort -r | head -n 1)
-
-if [[ $kamelets_tag == "" ]]; then
-    echo "INFO: no tag found for $camel_version camel version. Fallback to main branch."
-    kamelets_tag="main"
-fi
-
-popd
-echo "INFO: Kamelets version set at $kamelets_tag"
-sed -i "s/^KAMELET_CATALOG_REPO_TAG := .*$/KAMELET_CATALOG_REPO_TAG := $kamelets_tag/" $location/Makefile
-
-rm -rf /tmp/camel-k-runtime/ /tmp/camel-kamelets
\ No newline at end of file
+rm -rf /tmp/camel-k-runtime/
\ No newline at end of file
